@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 1490 2009-01-30 10:58:01Z fishbone $
+ * @version    SVN: $Id: m3Func.php 1716 2009-04-07 04:02:04Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -351,4 +351,16 @@ function convBytes($val)
 	}
 	return $val;
 }
+
+/**
+ * 簡易版デバッグ出力
+ *
+ * @param string $msg			出力メッセージ
+ * @return なし
+ */
+function debug($msg)
+{
+	global $gLogManager;
+	$gLogManager->debug(__METHOD__, $msg);
+}
 ?>
