@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 1630 2009-03-25 04:06:12Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 1758 2009-04-19 09:59:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -44,38 +44,30 @@ class BaseFrameContainer extends Core
 	 */
 	function process($request)
 	{
-		global $gLogManager;
-		global $gPageManager;
-		global $gEnvManager;
-		global $gAccessManager;
-		global $gConfigManager;
-		global $gSystemManager;
-		global $gFileManager;
-
 		// 実行コマンドを取得
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
 				
 		// インストール画面への制御は、install.phpファイルの作成、削除で制御する
 		// 最小限の設定が行われていない場合,DBに接続できない場合は、インストール画面へ
 		if (!defined('M3_STATE_IN_INSTALL')){
-			if (($gEnvManager->canUseDb() && $gSystemManager->canInitSystem()) ||		// システム初期化モードのとき
-				!$gConfigManager->isConfigured() || 									// 設定ファイルに設定がないとき
-				!$gEnvManager->canUseDb()){											// DBがまだ作成されていないとき
+			if (($this->gEnv->canUseDb() && $this->gSystem->canInitSystem()) ||		// システム初期化モードのとき
+				!$this->gConfig->isConfigured() || 									// 設定ファイルに設定がないとき
+				!$this->gEnv->canUseDb()){											// DBがまだ作成されていないとき
 				
 				// インストーラファイルがない場合は回復
-				$gFileManager->recoverInstaller();
+				$this->gFile->recoverInstaller();
 
-				$gPageManager->redirectToInstall();
+				$this->gPage->redirectToInstall();
 				return;
 			}
 		}
 
 		// 開始ログ出力
-		//$gLogManager->info(__METHOD__, 'フレーム作成開始');
+		//$this->gLog->info(__METHOD__, 'フレーム作成開始');
 
 		// ページ作成開始
 		// セッション変数読み込み
-		$gPageManager->startPage($request);
+		$this->gPage->startPage($request);
 		
 		if (!defined('M3_STATE_IN_INSTALL')){		// インストールモード以外のとき
 			// ############## ユーザごとの設定の読み込み ###################
@@ -83,24 +75,24 @@ class BaseFrameContainer extends Core
 			$clientId = $request->getCookieValue(M3_COOKIE_CLIENT_ID);
 			if ($clientId == ''){	// クライアントIDが設定されていないとき
 				// クライアントIDを生成
-				$clientId = $gAccessManager->createClientId();
+				$clientId = $this->gAccess->createClientId();
 			} else {
-				$gAccessManager->setClientId($clientId);	// クライアントIDを設定
+				$this->gAccess->setClientId($clientId);	// クライアントIDを設定
 			}
 			$request->setCookieValue(M3_COOKIE_CLIENT_ID, $clientId);
 			
 			// 引数での言語設定取得、言語変更可能な場合は変更
 			$lang = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_LANG);
-			if (!empty($lang) && $gEnvManager->getCanChangeLang()){
-				$gEnvManager->setCurrentLanguage($lang);
+			if (!empty($lang) && $this->gEnv->getCanChangeLang()){
+				$this->gEnv->setCurrentLanguage($lang);
 			}
 			// ################### URLアクセス制御 ######################
 			// 非公開URLへは管理権限がないとアクセスできない
 			$canAccess = true;		// アクセス可能かどうか
 			$isErrorAccess = false;		// 不正アクセスかどうか
 			$toAdmin = false;		// 管理画面へ遷移するかどうか
-			$isPublicUrl = $gPageManager->canAccessUrl();
-			if (!$isPublicUrl && !$gEnvManager->isSystemAdmin()){
+			$isPublicUrl = $this->gPage->canAccessUrl();
+			if (!$isPublicUrl && !$this->gEnv->isSystemAdmin()){
 				$canAccess = false;
 				$isErrorAccess = true;		// 不正アクセスかどうか
 			}
@@ -128,26 +120,26 @@ class BaseFrameContainer extends Core
 			}
 			// #################### アクセスログ記録 #######################
 			// DBが使用可能であれば、ログイン処理終了後、アクセスログを残す
-			if ($gEnvManager->canUseDb()) $gAccessManager->accessLog();
+			if ($this->gEnv->canUseDb()) $this->gAccess->accessLog();
 		
 			// アクセス不可のときはここで終了
 			if (!$canAccess){
 				if ($toAdmin){
 					// システム制御モードに変更
-					$gPageManager->setSystemHandleMode(1/*サイト非公開中*/);
+					$this->gPage->setSystemHandleMode(1/*サイト非公開中*/);
 					
 					// システム制御画面を表示
 					$this->_showSystemPage($request);
 				}
 				// 不正アクセスの場合は、アクセスエラーログを残す
-				if ($isErrorAccess) $this->gOpeLog->writeUserAccess(__METHOD__, '不正なアクセスを検出しました。', 2200, 'URL: ' . $this->gEnv->getCurrentRequestUri());
+				if ($isErrorAccess) $this->gOpeLog->writeUserAccess(__METHOD__, '不正なアクセスを検出しました。', 2200, 'アクセスをブロックしました。URL: ' . $this->gEnv->getCurrentRequestUri());
 				return;
 			}
 			// #################### URLの遷移 #######################
 			if ($this->_db->getSystemConfig(self::CF_MOBILE_AUTO_REDIRECT)){		// 携帯自動遷移を行う場合
 				// 携帯のときは携帯用URLへ遷移
-				if ($gEnvManager->isMobileAgent() && !$gEnvManager->getIsMobile()){
-					$gPageManager->redirect($gEnvManager->getDefaultMobileUrl());
+				if ($this->gEnv->isMobileAgent() && !$this->gEnv->getIsMobileSite()){
+					$this->gPage->redirect($this->gEnv->getDefaultMobileUrl());
 					return;
 				}
 			}
@@ -158,33 +150,33 @@ class BaseFrameContainer extends Core
 		if ($cmd == M3_REQUEST_CMD_INIT_DB){	// DB初期化オペレーションのとき
 		} else if ($cmd == M3_REQUEST_CMD_SHOW_POSITION){		// 表示位置を表示するとき
 			// 管理者権限がある場合のみ実行可能
-			if ($gEnvManager->isSystemAdmin()){
+			if ($this->gEnv->isSystemAdmin()){
 				// ポジションの表示画面のアクセスは、すべて管理機能URLで受け付ける
 				// ページIDを再設定
 				$pageId = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_ID);
-				if (empty($pageId)) $pageId = $gEnvManager->getDefaultPageId();		// 値がないときはデフォルトのページIDを設定
-				$gEnvManager->setCurrentPageId($pageId);
+				if (empty($pageId)) $pageId = $this->gEnv->getDefaultPageId();		// 値がないときはデフォルトのページIDを設定
+				$this->gEnv->setCurrentPageId($pageId);
 				
-				$gPageManager->showPosition(1);			// ポジションを表示
+				$this->gPage->showPosition(1);			// ポジションを表示
 			} else {
 				return;
 			}
 		} else if ($cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){		// 表示位置を表示するとき(ウィジェット付き)
 			// 管理者権限がある場合のみ実行可能
-			if ($gEnvManager->isSystemAdmin()){
+			if ($this->gEnv->isSystemAdmin()){
 				// ポジションの表示画面のアクセスは、すべて管理機能URLで受け付ける
 				// ページIDを再設定
 				$pageId = $request->trimValueOf(M3_REQUEST_PARAM_PAGE_ID);
-				if (empty($pageId)) $pageId = $gEnvManager->getDefaultPageId();		// 値がないときはデフォルトのページIDを設定
-				$gEnvManager->setCurrentPageId($pageId);
+				if (empty($pageId)) $pageId = $this->gEnv->getDefaultPageId();		// 値がないときはデフォルトのページIDを設定
+				$this->gEnv->setCurrentPageId($pageId);
 				
-				$gPageManager->showPosition(2);			// ウィジェット付きポジションを表示
+				$this->gPage->showPosition(2);			// ウィジェット付きポジションを表示
 			} else {
 				return;
 			}
 		} else if ($cmd == M3_REQUEST_CMD_GET_WIDGET_INFO){		// ウィジェット各種情報取得(AJAX用)
 			// ウィジェット情報取得
-			$gPageManager->getWidgetInfoByAjax($request);
+			$this->gPage->getWidgetInfoByAjax($request);
 			return;
 		} else if ($cmd == M3_REQUEST_CMD_SHOW_PHPINFO){	// phpinfoの表示
 			// phpinfo画面を表示
@@ -192,14 +184,14 @@ class BaseFrameContainer extends Core
 			return;
 		} else if ($cmd == M3_REQUEST_CMD_FIND_WIDGET){		// ウィジェットを検索し、前面表示
 			// 目的のウィジェットのあるページサブIDへ遷移
-			$gPageManager->redirectToUpdatedPageSubId($request);
+			$this->gPage->redirectToUpdatedPageSubId($request);
 			return;
 		} else if ($cmd == M3_REQUEST_CMD_SHOW_WIDGET){		// ウィジェットの単体表示
 			$createPage = false;		// ウィジェット単体処理モードに設定
-			$gPageManager->showWidget();	// ウィジェット表示
+			$this->gPage->showWidget();	// ウィジェット表示
 		} else if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){		// ウィジェットの設定管理
 			$createPage = false;		// ウィジェット単体処理モードに設定
-			$gPageManager->showWidget();	// ウィジェット表示
+			$this->gPage->showWidget();	// ウィジェット表示
 		} else if ($cmd == M3_REQUEST_CMD_DO_WIDGET){		// ウィジェット単体オペレーション
 			$createPage = false;		// ウィジェット単体処理モードに設定
 		}
@@ -212,15 +204,27 @@ class BaseFrameContainer extends Core
 			$curTemplate = $this->_defineTemplate($request);
 
 			// カレントのテンプレートIDを設定
-			$gEnvManager->setCurrentTemplateId($curTemplate);
+			$this->gEnv->setCurrentTemplateId($curTemplate);
 
+			// テンプレート情報を取得
+			$convType = 0;		// 変換処理タイプ(0=デフォルト(Joomla!v1.0)、-1=携帯用、1=Joomla!v1.5)
+			if ($this->gEnv->getIsMobileSite()){
+				$convType = -1;		// 携帯サイト用変換
+			} else {
+				// テンプレートタイプを取得(0=デフォルト(Joomla!v1.0)、1=Joomla!v1.5)
+				$convType = $this->gEnv->getCurrentTemplateType();
+				//if (!defined('M3_STATE_IN_INSTALL') && $this->_db->getTemplate($curTemplate, $row)){// インストールモード以外のとき
+				//	if ($row['tm_type'] == 1) $convType = 1;		// Joomla!v1.5テンプレートのとき
+				//}
+			}
+			
 			// バッファリングの準備
 			if (method_exists($this, '_prepareBuffer')) $this->_prepareBuffer($request);
 			
 			// ################### バッファリング開始 ######################
 			// ob_end_flush()までの出力をバッファリングする
-			if ($gEnvManager->getIsMobile()){// 携帯用サイトの場合は出力エンコーディングを変更
-				$mobileEncoding = $gEnvManager->getMobileEncoding();		// 携帯用エンコーディングを取得
+			if ($convType == -1){// 携帯用サイトの場合は出力エンコーディングを変更
+				$mobileEncoding = $this->gEnv->getMobileEncoding();		// 携帯用エンコーディングを取得
 				//mb_internal_encoding("UTF-8");
 				mb_http_output($mobileEncoding);
 				ob_start("mb_output_handler"); // 出力のバッファリング開始
@@ -231,21 +235,44 @@ class BaseFrameContainer extends Core
 			// サブクラスの前処理を実行
 			$this->_preBuffer($request);
 		
-			// Joomlaテンプレート用定義
-			global $mosConfig_absolute_path;
-			global $mosConfig_live_site;
-			global $mosConfig_sitename;
-			global $mosConfig_favicon;
-			global $mosConfig_sef;
-			global $cur_template;
-			global $mainframe;
-			$GLOBALS['cur_template'] = $curTemplate;
-			require_once($gEnvManager->getJoomlaRootPath() . '/mosFunc.php');
-			require_once($gEnvManager->getJoomlaRootPath() . '/includes/sef.php');
+			if ($convType == 1){		// Joomla!v1.5テンプレートのとき
+				require_once($this->gEnv->getJoomlaRootPath() . '/JParameter.php');
+				require_once($this->gEnv->getJoomlaRootPath() . '/JModuleRender.php');
+								
+				// 設定ファイルの読み込み
+				$params = array();
+				$paramFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/params.ini';
+				if (is_readable($paramFile)){
+					$content = file_get_contents($paramFile);
+					$params = new JParameter($content);
+				}
+		
+				// Joomla!v1.5用の設定
+				define('_JEXEC', 1);
+				define('JPATH_BASE', dirname(__FILE__));
+				define('DS', DIRECTORY_SEPARATOR);
+				$this->language = $this->gEnv->getCurrentLanguage();
+				$this->template = $curTemplate;
+				$this->baseurl  = $this->gEnv->getRootUrl();
+				$this->params   = $params;
+				global $mainframe;
+			} else {			// デフォルト(Joomla!v1.0テンプレート)テンプレートのとき(PC用および携帯用)
+				// Joomlaテンプレート用定義
+				global $mosConfig_absolute_path;
+				global $mosConfig_live_site;
+				global $mosConfig_sitename;
+				global $mosConfig_favicon;
+				global $mosConfig_sef;
+				global $cur_template;
+				global $mainframe;
+				$GLOBALS['cur_template'] = $curTemplate;
+				require_once($this->gEnv->getJoomlaRootPath() . '/mosFunc.php');
+				require_once($this->gEnv->getJoomlaRootPath() . '/includes/sef.php');
+			}
 		
 			// ################### テンプレート読み込み ###################
 			// テンプレートのポジションタグからウィジェットが実行される
-			$templateIndexFile = $gEnvManager->getTemplatesPath() . '/' . $curTemplate . '/index.php';
+			$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/index.php';
 			if (file_exists($templateIndexFile)){
 				require_once($templateIndexFile);
 				//echo '<!-- ' . time() . ' -->' . M3_NL;
@@ -260,11 +287,16 @@ class BaseFrameContainer extends Core
 			$srcContents = ob_get_contents();
 			ob_clean();
 		
+			// Joomla!タグの変換処理(ウィジェット実行)
+			if ($convType == 1){		// Joomla!v1.5テンプレートのとき
+				$srcContents = $this->gPage->launchWidgetByJoomlaTag($srcContents);
+			}
+			
 			// 遅延実行ウィジェットの出力を埋め込む
-			$destContents = $gPageManager->lateLaunchWidget($request, $srcContents);
+			$destContents = $this->gPage->lateLaunchWidget($request, $srcContents);
 		
 			// 携帯インターフェイスのときのときは、手動変換後、バイナリコード(絵文字等)を埋め込む
-			if ($gEnvManager->getIsMobile()){
+			if ($convType == -1){
 				// コンテンツ変換メソッドがある場合は実行
 				if (method_exists($this, '_convContents')){		
 					$destContents = mb_convert_encoding($destContents, $mobileEncoding, M3_ENCODING);		// 出力するコードに変換
@@ -274,18 +306,18 @@ class BaseFrameContainer extends Core
 				$destContents = $this->_convContents($destContents);
 			
 				// ページ作成終了処理(HTTPヘッダ出力)
-				$destContents .= $gPageManager->endPage($request, true/*出力を取得*/);		// 最終HTMLを追加
+				$destContents .= $this->gPage->endPage($request, true/*出力を取得*/);		// 最終HTMLを追加
 			
 				// バッファを破棄
 				ob_end_flush();
 			
 				// クライアントにデータを送信
 				echo $destContents;
-			} else {
+			} else {			// PC用サイトの場合
 				echo $destContents;
 		
 				// ページ作成終了処理(HTTPヘッダ出力)
-				$gPageManager->endPage($request);
+				$this->gPage->endPage($request);
 	
 				// mb_http_outputで設定したエンコーディングに変換して、バッファ内容を送信(クライアントへの送信完了)
 				ob_end_flush();
@@ -314,7 +346,7 @@ class BaseFrameContainer extends Core
 				}
 			}
 			// 管理権限がない場合は、ウィジェットのアクセス権限をチェックする
-			if (!$gEnvManager->isSystemAdmin() && !$gAccessManager->isValidAdminKey($request) && !$this->_db->canAccessWidget($widgetId)){
+			if (!$this->gEnv->isSystemAdmin() && !$this->gAccess->isValidAdminKey($request) && !$this->_db->canAccessWidget($widgetId)){
 				// アクセスエラーのログを残す
 				$this->_db->writeWidgetLog($widgetId, 1/*単体実行*/, $cmd, self::ERR_MESSAGE_ACCESS_DENY);
 				
@@ -329,7 +361,7 @@ class BaseFrameContainer extends Core
 				$curTemplate = $this->_defineTemplate($request, false);
 
 				// カレントのテンプレートIDを設定
-				$gEnvManager->setCurrentTemplateId($curTemplate);
+				$this->gEnv->setCurrentTemplateId($curTemplate);
 			}
 			
 			// ################### バッファリング開始 ######################
@@ -340,16 +372,16 @@ class BaseFrameContainer extends Core
 			$this->_preBuffer($request);
 		
 			// 作業中のウィジェットIDを設定
-			$gEnvManager->setCurrentWidgetId($widgetId);
+			$this->gEnv->setCurrentWidgetId($widgetId);
 			
 			// ウィジェット用のHTMLヘッダを出力
-			$gPageManager->startWidget($cmd);
+			$this->gPage->startWidget($cmd);
 
 			// 指定のウィジェットを実行
 			if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){		// ウィジェット設定のとき
-				$widgetIndexFile = $gEnvManager->getWidgetsPath() . '/' . $widgetId . '/admin/index.php';		// 管理用画面
+				$widgetIndexFile = $this->gEnv->getWidgetsPath() . '/' . $widgetId . '/admin/index.php';		// 管理用画面
 			} else {
-				$widgetIndexFile = $gEnvManager->getWidgetsPath() . '/' . $widgetId . '/index.php';
+				$widgetIndexFile = $this->gEnv->getWidgetsPath() . '/' . $widgetId . '/index.php';
 			}
 			if (file_exists($widgetIndexFile)){
 				// 実行のログを残す
@@ -361,10 +393,10 @@ class BaseFrameContainer extends Core
 			}
 			
 			// ウィジェット用のタグを閉じる
-			$gPageManager->endWidget($cmd);
+			$this->gPage->endWidget($cmd);
 		
 			// 作業中のウィジェットIDを解除
-			$gEnvManager->setCurrentWidgetId('');
+			$this->gEnv->setCurrentWidgetId('');
 			
 			// サブクラスの後処理の呼び出し
 			$this->_postBuffer($request);
@@ -376,13 +408,13 @@ class BaseFrameContainer extends Core
 				ob_clean();
 				
 				// 追加変換処理
-				$destContents = $gPageManager->lateLaunchWidget($request, $srcContents);
+				$destContents = $this->gPage->lateLaunchWidget($request, $srcContents);
 				
 				echo $destContents;
 			}
 			
 			// ページ作成終了処理(HTTPヘッダ出力)
-			$gPageManager->endPage($request);
+			$this->gPage->endPage($request);
 			
 			// バッファ内容を送信(クライアントへの送信完了)
 			ob_end_flush();
@@ -390,11 +422,11 @@ class BaseFrameContainer extends Core
 		if (!defined('M3_STATE_IN_INSTALL')){		// インストールモード以外のとき
 			// #################### アクセスログ記録 #######################
 			// DBが使用可能であれば、アクセスログのユーザを登録
-			if ($gEnvManager->canUseDb()) $gAccessManager->accessLogUser();
+			if ($this->gEnv->canUseDb()) $this->gAccess->accessLogUser();
 		}
 			
 		// 終了ログ出力
-		//$gLogManager->info(__METHOD__, 'フレーム作成終了');
+		//$this->gLog->info(__METHOD__, 'フレーム作成終了');
 	}
 	/**
 	 * テンプレートを決定
@@ -405,8 +437,6 @@ class BaseFrameContainer extends Core
 	 */
 	function _defineTemplate($request, $useSubClassDefine = true)
 	{
-		global $gEnvManager;
-		
 		// ########### テンプレートID(ディレクトリ名)を設定 ############
 		// テンプレートIDの指定の方法は2パターン
 		// 　1.サブクラスで固定に指定
@@ -440,11 +470,11 @@ class BaseFrameContainer extends Core
 				$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){	// 表示位置を表示するとき(ウィジェット付き)
 				
 				// URLの引数として、ページIDとページサブIDが指定されてくる
-				if ($pageId == $gEnvManager->getDefaultPageId()){		// 通常サイトのとき
+				if ($pageId == $this->gEnv->getDefaultPageId()){		// 通常サイトのとき
 					$curTemplate = $this->_db->getDefaultTemplateId();
-				} else if ($pageId == $gEnvManager->getDefaultMobilePageId()){		// 携帯サイトのとき
+				} else if ($pageId == $this->gEnv->getDefaultMobilePageId()){		// 携帯サイトのとき
 					$curTemplate = $this->_db->getDefaultMobileTemplateId();		// 携帯用デフォルトテンプレート
-				} else if ($pageId == $gEnvManager->getDefaultAdminPageId()){		// 管理サイトのとき
+				} else if ($pageId == $this->gEnv->getDefaultAdminPageId()){		// 管理サイトのとき
 					$curTemplate = '_admin';
 				} else if (empty($pageId)){			// ページIDが指定されていないときは、ウィジェットを表示しないテンプレートのみの表示
 					// テンプレートIDが指定されている場合はテンプレートを変更
@@ -452,13 +482,13 @@ class BaseFrameContainer extends Core
 					if (!empty($template)) $curTemplate = $template;
 				}
 			} else {
-				if (!$gEnvManager->getIsMobile()) $curTemplate = $request->getSessionValue(M3_SESSION_CURRENT_TEMPLATE);// 携帯サイトでないときはセッション値を取得
+				if (!$this->gEnv->getIsMobileSite()) $curTemplate = $request->getSessionValue(M3_SESSION_CURRENT_TEMPLATE);// 携帯サイトでないときはセッション値を取得
 			}
 		}
 
 		// セッションにないときは、DBより取得
 		if ($curTemplate == ''){
-			if ($gEnvManager->getIsMobile()){// 携帯用サイトの場合
+			if ($this->gEnv->getIsMobileSite()){// 携帯用サイトの場合
 				$curTemplate = $this->_db->getDefaultMobileTemplateId();		// 携帯用デフォルトテンプレート
 			} else {
 				$curTemplate = $this->_db->getDefaultTemplateId();
@@ -472,7 +502,7 @@ class BaseFrameContainer extends Core
 			if ($cmd == M3_REQUEST_CMD_SHOW_POSITION ||				// 表示位置を表示するとき
 				$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){	// 表示位置を表示するとき(ウィジェット付き)
 			} else {
-				if (!$gEnvManager->getIsMobile() && !$isSubclassDefined){		// PC用画面でサブクラス固定でないとき場合は保存
+				if (!$this->gEnv->getIsMobileSite() && !$isSubclassDefined){		// PC用画面でサブクラス固定でないとき場合は保存
 					$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $curTemplate);
 				}
 			}
@@ -509,13 +539,10 @@ class BaseFrameContainer extends Core
 	 */
 	function _showSystemPage($request)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		
 		// ページIDを設定
 		$basename = 'admin_index';
-		$gEnvManager->setCurrentPageId($basename);								// ここでデフォルトページサブIDが再設定される
-		$gEnvManager->setCurrentPageSubId($gEnvManager->getDefaultPageSubId());// デフォルトページサブIDをカレントにする
+		$this->gEnv->setCurrentPageId($basename);								// ここでデフォルトページサブIDが再設定される
+		$this->gEnv->setCurrentPageSubId($this->gEnv->getDefaultPageSubId());// デフォルトページサブIDをカレントにする
 		
 		// テンプレートの設定
 		// DBで設定されている値を取得し、なければ管理用デフォルトテンプレートを使用
@@ -523,7 +550,7 @@ class BaseFrameContainer extends Core
 		if (empty($curTemplate)) $curTemplate = self::ADMIN_TEMPLATE;// 管理用テンプレート
 
 		// カレントのテンプレートIDを設定
-		$gEnvManager->setCurrentTemplateId($curTemplate);
+		$this->gEnv->setCurrentTemplateId($curTemplate);
 		
 		// ################### バッファリング開始 ######################
 		// ob_end_flush()までの出力をバッファリングする
@@ -541,12 +568,12 @@ class BaseFrameContainer extends Core
 		global $cur_template;
 		global $mainframe;
 		$GLOBALS['cur_template'] = $curTemplate;
-		require_once($gEnvManager->getJoomlaRootPath() . '/mosFunc.php');
-		require_once($gEnvManager->getJoomlaRootPath() . '/includes/sef.php');
+		require_once($this->gEnv->getJoomlaRootPath() . '/mosFunc.php');
+		require_once($this->gEnv->getJoomlaRootPath() . '/includes/sef.php');
 	
 		// ################### テンプレート読み込み ###################
 		// テンプレートのポジションタグからウィジェットが実行される
-		$templateIndexFile = $gEnvManager->getTemplatesPath() . '/' . $curTemplate . '/index.php';
+		$templateIndexFile = $this->gEnv->getTemplatesPath() . '/' . $curTemplate . '/index.php';
 		if (file_exists($templateIndexFile)){
 			require_once($templateIndexFile);
 		} else {
@@ -561,11 +588,11 @@ class BaseFrameContainer extends Core
 		ob_clean();
 		
 		// 遅延実行ウィジェットの出力を埋め込む
-		$destContents = $gPageManager->lateLaunchWidget($request, $srcContents);
+		$destContents = $this->gPage->lateLaunchWidget($request, $srcContents);
 		echo $destContents;
 		
 		// ページ作成終了処理(HTTPヘッダ出力)
-		$gPageManager->endPage($request);
+		$this->gPage->endPage($request);
 	
 		// バッファ内容を送信(クライアントへの送信完了)
 		ob_end_flush();
@@ -578,9 +605,6 @@ class BaseFrameContainer extends Core
 	 */
 	function _showPhpinfoPage($request)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		
 		// ################### バッファリング開始 ######################
 		// ob_end_flush()までの出力をバッファリングする
 		ob_start();
@@ -590,5 +614,16 @@ class BaseFrameContainer extends Core
 		// バッファ内容を送信(クライアントへの送信完了)
 		ob_end_flush();
 	}
+	/**
+	 * ウィジェット数を取得(Joomla!v1.5テンプレート専用)
+	 *
+	 * @param string $pos		ポジション
+	 * @return int				ウィジェット数
+	 */
+	function countModules($pos)
+	{
+		$count = $this->gPage->getWidgetsCount($pos);
+		return $count;
+	}
 }
 ?>
