@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 1617 2009-03-23 04:57:16Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 1663 2009-03-28 11:30:24Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -1107,6 +1107,15 @@ class BaseWidgetContainer extends Core
 		$this->warningMessage	= array_merge($this->warningMessage, $warningMessage);	// ユーザ操作のエラー
 		$this->guidanceMessage	= array_merge($this->guidanceMessage, $guidanceMessage);	// ガイダンス
 	}
+	/**
+	 * グローバルメッセージを追加取得する
+	 *
+	 * @return 				なし
+	 */
+	function getGlobalMsg()
+	{
+		$this->addMsg($this->gMessage->getErrorMessage(), $this->gMessage->getWarningMessage(), $this->gMessage->getGuidanceMessage());
+	}
 	/**
 	 * メッセージテーブルにアプリケーションエラーメッセージを設定する
 	 *
