@@ -1,6 +1,6 @@
 <?php
 /**
- * index.php用コンテナクラス
+ * 携帯index.php用コンテナクラス
  *
  * PHP versions 5
  *
@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_indexFrameContainer.php 357 2008-03-04 06:32:30Z fishbone $
+ * @version    SVN: $Id: m_indexFrameContainer.php 785 2008-06-23 10:17:20Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseFrameContainer.php');
@@ -26,29 +26,18 @@ class m_indexFrameContainer extends BaseFrameContainer
 		parent::__construct();
 	}
 	/**
-	 * フレーム単位のアクセス制御
-	 *
-	 * 同フレーム(同.phpファイル)での共通のアクセス制御を行う
+	 * バッファリングの準備
 	 *
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 * @return bool							true=アクセス可能、falseアクセス不可
 	 */
-	 /*
-	function _checkAccess($request)
+	function _prepareBuffer($request)
 	{
-		// 受け付けるコマンドを判断
-		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
-		if ($cmd == '' ||								// コマンドなし
-			$cmd == M3_REQUEST_CMD_CHANGE_TEMPLATE ||	// テンプレート変更
-			$cmd == M3_REQUEST_CMD_SHOW_POSITION ||		// 表示位置を表示するとき
-			$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET ||		// 表示位置を表示するとき(ウィジェット付き)
-			$cmd == M3_REQUEST_CMD_FIND_WIDGET ||		// ウィジェットを検索
-			$cmd == M3_REQUEST_CMD_DO_WIDGET){	// ウィジェット単体実行
-			return true;
-		} else {
-			return false;
-		}
-	}*/
+		global $gEnvManager;
+		
+		// 携帯の機種に応じて出力エンコーディングを設定する
+		//$encode = 'SJIS';
+		//$gEnvManager->setMobileEncoding($encode);
+	}
 	/**
 	 * ビュー作成の前処理
 	 *
@@ -76,5 +65,19 @@ class m_indexFrameContainer extends BaseFrameContainer
 	{
 		return '';
 	}
+	/**
+	 * コンテンツを変換
+	 *
+	 * @param string $src					変換元コンテンツ
+	 * @return 								変換後コンテンツ
+	 */
+	function _convContents($src)
+	{
+		global $gTextConvManager;
+		
+		// 絵文字変換を行う
+		$gTextConvManager->convEmoji($src, $dest);
+		return $dest;
+	}
 }
 ?>
