@@ -10,10 +10,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseDb.php 1261 2008-11-21 08:43:11Z fishbone $
+ * @version    SVN: $Id: baseDb.php 1296 2008-11-28 12:04:35Z fishbone $
  * @link       http://www.magic3.org
  */
-class BaseDb
+require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
+
+class BaseDb extends Core
 {
 	private static $_con = null;		// DBコネクション
 	private static $_tranStatus;		// トランザクションの状態
@@ -42,6 +44,9 @@ class BaseDb
 	 */
 	function __construct()
 	{
+		// 親クラスを呼び出す
+		parent::__construct();
+		
 		$this->_connect_dsn			= M3_DB_CONNECT_DSN;				// DB接続情報
 		$this->_connect_user		= M3_DB_CONNECT_USER;				// DB接続ユーザ
 		$this->_connect_password	= M3_DB_CONNECT_PASSWORD;			// DB接続パスワード
@@ -356,14 +361,15 @@ class BaseDb
 		
 		// ログにエラーメッセージを出力
 		if (!empty($message)) $msg = ': ' . $message;
-		
+
 		// バックトレース出力
-		ob_start();
+		// メモリ不足でdebug_print_backtrace()でフリーズするのでコメントアウトする(2008/11/28)
+/*		ob_start();
 		debug_print_backtrace();
 		$backTraceMsg = ob_get_contents();
 		ob_end_clean();
+		$msg .= ' [BACKTRACE]' . $backTraceMsg;*/
 		
-		$msg .= ' [BACKTRACE]' . $backTraceMsg;
 		$gLogManager->error(__METHOD__, 'DBエラー発生: ' . $ex->getMessage() . $msg);
 	}
 	/**
