@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: systemDb.php 1544 2009-03-04 03:45:36Z fishbone $
+ * @version    SVN: $Id: systemDb.php 1630 2009-03-25 04:06:12Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/baseDb.php');
@@ -340,7 +340,7 @@ class SystemDb extends BaseDb
 	 *
 	 * アクセス可能なウィジェットは以下のすべての条件を満たすもの
 	 * ・ウィジェット単体起動が許可されている
-	 * ・ウィジェットが公開ページ上にある
+	 * ・ウィジェットが公開ページ上にあるか、または、ページ共通属性が設定されている
 	 *
 	 * @param string $widgetId		ウィジェットID
 	 * @param int    $setId			定義セットID
@@ -356,7 +356,8 @@ class SystemDb extends BaseDb
 		$queryStr .=   'AND pd_visible = true ';			// ウィジェットは表示中
 		$queryStr .=   'AND wd_deleted = false ';			// ウィジェットは削除されていない
 		$queryStr .=   'AND wd_enable_operation = true ';	// 単体実行可能
-		$queryStr .=   'AND pg_active = true ';			// 公開中のページ
+		//$queryStr .=   'AND pg_active = true ';			// 公開中のページ
+		$queryStr .=   'AND (pd_sub_id = \'\' OR pg_active = true) ';		// ページ共通ウィジェットか公開中のページ上のウィジェット
 		$params = array($widgetId, $setId);
 		$ret = $this->isRecordExists($queryStr, $params);
 		return $ret;
