@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 1.7.x SVN: $Id: global.php 1696 2009-04-02 06:18:26Z fishbone $
+ * @version    Release 1.7.x SVN: $Id: global.php 1740 2009-04-15 10:06:43Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -42,8 +42,8 @@ define('M3_ENCODING',	'UTF-8');		// 内部エンコーディング
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'1.7.23');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2009/4/2');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.7.25');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2009/4/13');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -82,6 +82,7 @@ define('M3_SYSTEM_TAG_CHANGE_TEMPLATE',	'_sel_template');		// テンプレート
 // クッキー保存値
 define('M3_COOKIE_CLIENT_ID',	'CID');				// クライアントID
 define('M3_COOKIE_CART_ID',		'CARTID');			// EコマースカートID
+define('M3_COOKIE_DISP_ID',		'DISPID');			// クライアント画面設定ID
 
 // 作業用
 define('M3_SYSTEM_WORK_DIR_PATH', 				'/tmp');			// 作業用ディレクトリ
@@ -209,6 +210,7 @@ require_once(dirname(__FILE__) . '/manager/initialManager.php');
 require_once(dirname(__FILE__) . '/manager/cmdParamManager.php');
 require_once(dirname(__FILE__) . '/manager/textConvManager.php');
 require_once(dirname(__FILE__) . '/manager/helpManager.php');
+require_once(dirname(__FILE__) . '/manager/dispManager.php');
 
 // マネージャーの作成、初期化
 $gLogManager 		= new LogManager();		// これよりロギング可能
@@ -233,6 +235,7 @@ $gInitialManager	= new InitialManager();
 $gCmdParamManager	= new CmdParamManager();
 $gTextConvManager	= new TextConvManager();
 $gHelpManager		= new HelpManager();
+$gDispManager		= new DispManager();
 
 // 追加クラスの読み込み
 $gInstanceManager->loadAddonClass();
