@@ -10,10 +10,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: analyzeManager.php 1090 2008-10-20 07:49:19Z fishbone $
+ * @version    SVN: $Id: analyzeManager.php 1287 2008-11-27 05:00:49Z fishbone $
  * @link       http://www.magic3.org
  */
-class AnalyzeManager
+require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
+
+class AnalyzeManager extends Core
 {
 	private $db;						// DBオブジェクト
 	
@@ -22,10 +24,13 @@ class AnalyzeManager
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-			
+		//global $gInstanceManager;
+		// 親クラスを呼び出す
+		parent::__construct();
+		
 		// システムDBオブジェクト取得
-		$this->db = $gInstanceManager->getSytemDbObject();
+		//$this->db = $gInstanceManager->getSytemDbObject();
+		$this->db = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * コンテンツのビューカウントを更新
