@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: configManager.php 1287 2008-11-27 05:00:49Z fishbone $
+ * @version    SVN: $Id: configManager.php 1460 2009-01-22 13:34:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -46,8 +46,7 @@ class ConfigManager extends Core
 	 */
 	public function configFilePath()
 	{
-		global $gEnvManager;
-		return $gEnvManager->getIncludePath() . '/' . $this->configFile;
+		return $this->gEnv->getIncludePath() . '/' . $this->configFile;
 	}
 	/**
 	 * 設定ファイルが作成可能かどうか
@@ -56,10 +55,9 @@ class ConfigManager extends Core
 	 */
 	public function isConfigFileWritable()
 	{
-		global $gEnvManager;
-		if (file_exists($gEnvManager->getIncludePath() . '/' . $this->configFile) && is_writable($gEnvManager->getIncludePath() . '/' . $this->configFile)){
+		if (file_exists($this->gEnv->getIncludePath() . '/' . $this->configFile) && is_writable($this->gEnv->getIncludePath() . '/' . $this->configFile)){
 			return true;
-		} else if (is_writable($gEnvManager->getIncludePath())){// ディレクトリが書き込み可能か
+		} else if (is_writable($this->gEnv->getIncludePath())){// ディレクトリが書き込み可能か
 			return true;
 		} else {
 			return false;
@@ -72,8 +70,7 @@ class ConfigManager extends Core
 	 */
 	public function isConfigDirWritable()
 	{
-		global $gEnvManager;
-		if (is_writable($gEnvManager->getIncludePath())){// ディレクトリが書き込み可能か
+		if (is_writable($this->gEnv->getIncludePath())){// ディレクトリが書き込み可能か
 			return true;
 		} else {
 			return false;
@@ -100,19 +97,19 @@ class ConfigManager extends Core
 	/**
 	 * 設定ファイルの作成
 	 *
+	 * @param string $msg		エラーメッセージ
 	 * @return bool				true=成功、false=失敗
 	 */
-	function updateConfigFile()
+	function updateConfigFile(&$msg)
 	{
-		global $gLogManager;
-		global $gEnvManager;
-		
 		// 設定ファイルのフルパス
-		$configFilePath = $gEnvManager->getIncludePath() . '/' . $this->configFile;
+		$configFilePath = $this->gEnv->getIncludePath() . '/' . $this->configFile;
 		
 		// 現在の設定ファイルを読み込む
 		if (!($file = @fopen($configFilePath, "r"))){
- 			$gLogManager->error(__METHOD__, '設定ファイルのオープンに失敗しました ファイル=' . $configFilePath);
+			$errMsg = '設定ファイルのオープンに失敗しました ファイル=' . $configFilePath;
+ 			$this->gLog->error(__METHOD__, $errMsg);
+			$msg = $errMsg;
  			return false;
 		}
 		$content = @fread($file, filesize($configFilePath));
@@ -124,29 +121,47 @@ class ConfigManager extends Core
 				$content = preg_replace("/^[ \t]*define\([ \t]*[\"']" . $key . "[\"'][ \t]*,[ \t]*[\"'].*[\"'][ \t]*\)/m",
 					"define('" . $key . "', '" . addslashes($val) . "')", $content);
 			} else {
-				$gLogManager->error(__METHOD__, '設定ファイルにキーが見つかりません key=' . $key);
+				$errMsg = '設定ファイルにキーが見つかりません key=' . $key;
+				$this->gLog->error(__METHOD__, $errMsg);
+				$msg = $errMsg;
 				return false;
 			}
 		}
 		
 		// テンポラリファイルに保存
-		//$tmpFilename = tempnam("/tmp", "m3_");
-		$tmpFilename = tempnam(M3_SYSTEM_WORK_DIR_PATH, "m3_");
-		$tmpFHandle = fopen($tmpFilename, "w");
+		if (!($tmpFilename = tempnam(M3_SYSTEM_WORK_DIR_PATH, "m3_"))){
+			$errMsg = 'テンポラリファイルの作成に失敗しました ディレクトリ=' . M3_SYSTEM_WORK_DIR_PATH;
+ 			$this->gLog->error(__METHOD__, $errMsg);
+			$msg = $errMsg;
+ 			return false;
+		}
+		if (!($tmpFHandle = fopen($tmpFilename, "w"))){
+			$errMsg = 'テンポラリファイルのオープンに失敗しました ファイル=' . $tmpFilename;
+ 			$this->gLog->error(__METHOD__, $errMsg);
+			$msg = $errMsg;
+			
+			// 作成した設定ファイルを削除
+			unlink($tmpFilename);
+ 			return false;
+		}
 		fwrite($tmpFHandle, $content);
 		fclose($tmpFHandle);
 		
 		// 現在の設定ファイルとテンポラリファイルを入れ替え
 		$tmpConfigFilePath = $configFilePath . '_tmp';
 		if (!rename($configFilePath, $tmpConfigFilePath)){
-			$gLogManager->error(__METHOD__, '設定ファイルを退避できません');
+			$errMsg = '設定ファイルを退避できません';
+			$this->gLog->error(__METHOD__, $errMsg);
+			$msg = $errMsg;
 			
 			// 作成した設定ファイルを削除
 			unlink($tmpFilename);
 			return false;
 		}
 		if (!rename($tmpFilename, $configFilePath)){
-			$gLogManager->error(__METHOD__, '設定ファイルを作成できません');
+			$errMsg = '設定ファイルを作成できません';
+			$this->gLog->error(__METHOD__, $errMsg);
+			$msg = $errMsg;
 			
 			// 作成した設定ファイルを削除
 			unlink($tmpFilename);
