@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 1658 2009-03-28 01:06:41Z fishbone $
+ * @version    SVN: $Id: envManager.php 1739 2009-04-15 02:59:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -43,7 +43,7 @@ class EnvManager extends Core
 	private $siteCopyRight;		// サイトコピーライト
 	private $siteEmail;			// サイトEメール
 	private $widgetLog;			// ウィジェット実行ログを残すかどうか
-	private $isMobile;			// 携帯アクセスかどうか
+	private $isMobileSite;		// 携帯URLアクセスかどうか
 	private $mobileEncoding;	// 携帯用の入力、出力エンコーディング
 	private $workDir;			// 作業用ディレクトリ
 	private $userAgent = array();	// アクセス端末の情報
@@ -551,14 +551,13 @@ class EnvManager extends Core
 	public function setCurrentTemplateId($name)
 	{
 		$this->currentTemplateId = $name;
-		
-		// DBが使用できないときは終了
-		if (!$this->canUseDb) return;
 
 		// テンプレートの属性を取得
 		$this->currentTemplateType = 0;
-		if ($this->db->getTemplate($name, $row)){
-			if ($row['tm_mobile']) $this->currentTemplateType = 1;		// 携帯の場合
+		if ($this->canUseDb){		// DB使用可能なとき
+			if ($this->db->getTemplate($name, $row)){
+				$this->currentTemplateType = $row['tm_type'];		// テンプレートタイプ
+			}
 		}
 	}
 	/**
@@ -1225,9 +1224,9 @@ class EnvManager extends Core
 	 * @param bool $status			true=携帯アクセス、false=通常アクセス
 	 * @return 			なし
 	 */
-	public function setIsMobile($status)
+	public function setIsMobileSite($status)
 	{
-		$this->isMobile = $status;
+		$this->isMobileSite = $status;
 		
 		if ($status){
 			// ##### 携帯用の設定 #####
@@ -1240,9 +1239,9 @@ class EnvManager extends Core
 	 *
 	 * @return bool		true=携帯アクセス、false=通常アクセス
 	 */
-	public function getIsMobile()
+	public function getIsMobileSite()
 	{
-		return $this->isMobile;
+		return $this->isMobileSite;
 	}
 	/**
 	 * 携帯端末でのアクセスかどうか
