@@ -13,7 +13,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: launchManager.php 1287 2008-11-27 05:00:49Z fishbone $
+ * @version    SVN: $Id: launchManager.php 1736 2009-04-14 06:47:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -92,7 +92,7 @@ class LaunchManager extends Core
 		$pathCount = count($pathArray);
 		$accessAdmin = false;
 		
-		if ($gEnvManager->getIsMobile()){		// 携帯アクセスのとき
+		if ($gEnvManager->getIsMobileSite()){		// 携帯アクセスのとき
 			// 管理画面へのアクセスかどうかチェック
 			if ($pathArray[$pathCount -2] == 'admin' && $pathArray[$pathCount -3] == $widgetId){
 				$accessAdmin = true;
@@ -253,7 +253,7 @@ class LaunchManager extends Core
 		global $gRequestManager;
 
 		// 携帯からのアクセスを設定
-		$gEnvManager->setIsMobile(true);
+		$gEnvManager->setIsMobileSite(true);
 		
 		// ルートから$filepathへの相対パスで「FrameContainer.php」の先頭につける
 		// サフィックスを作成する
