@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1699 2009-04-03 07:14:31Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1753 2009-04-18 06:50:19Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/core.php');
@@ -134,7 +134,7 @@ class PageManager extends Core
 
 	// Magic3用スクリプト
 	const M3_ADMIN_SCRIPT_FILENAME			= 'm3admin1.1.6.js';				// 管理機能用スクリプト
-	const M3_ADMIN_WIDGET_SCRIPT_FILENAME	= 'm3admin_widget1.3.1.js';	// 管理機能(ウィジェット操作)用スクリプト
+	const M3_ADMIN_WIDGET_SCRIPT_FILENAME	= 'm3admin_widget1.3.2.js';	// 管理機能(ウィジェット操作)用スクリプト
 	const M3_ADMIN_WIDGET_CSS_FILE			= '/m3/widget.css';			// 管理機能(ウィジェット操作)用CSSファイル
 	const M3_STD_SCRIPT_FILENAME			= 'm3std1.3.2.js';
 	//const M3_AJAX_SCRIPT_FILENAME			= 'm3ajax1.1.js';
@@ -480,6 +480,7 @@ class PageManager extends Core
 		global $gInstanceManager;
 		global $gAccessManager;
 		global $gSystemManager;
+		global $gDispManager;
 		
 		// 実行コマンドを取得
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
@@ -519,6 +520,9 @@ class PageManager extends Core
 		$userInfo = $gRequestManager->getSessionValueWithSerialize(M3_SESSION_USER_INFO);
 		$gInstanceManager->setUserInfo($userInfo);
 		
+		// 画面設定取得
+		$gDispManager->load();
+			
 		// 必要なスクリプトがあるときは追加
 		if (!defined('M3_STATE_IN_INSTALL')){		// インストール時は実行しない
 			if ($gEnvManager->isAdminDirAccess()){		// 管理画面へのアクセスのとき
@@ -602,6 +606,7 @@ class PageManager extends Core
 		global $gAjaxManager;
 		global $gRequestManager;
 		global $gInstanceManager;
+		global $gDispManager;
 		
 		// ページ作成処理を中断するかどうか
 		if ($this->isAbort) return '';
@@ -624,6 +629,9 @@ class PageManager extends Core
 		$userInfo = $gInstanceManager->getUserInfo();
 		$gRequestManager->setSessionValueWithSerialize(M3_SESSION_USER_INFO, $userInfo);
 		
+		// 画面設定保存
+		$gDispManager->save();
+			
 		// キャッシュリミッタは、各リクエスト毎に(アウトプットバッファー が無効な場合は、
 		// session_start()がコールされる 前に) session_cache_limiter()をコールする必要がある。
 	 	// キャッシュを残す設定
@@ -682,6 +690,57 @@ class PageManager extends Core
 		
 		exit;
 	}
+	/**
+	 * Joomla!v1.5タグを読み込んでウィジェット実行
+	 *
+	 * @param string         $srcBuf		バッファデータ
+	 * @return string						変換後文字列
+	 */
+	function launchWidgetByJoomlaTag($srcBuf)
+	{
+		$replace = array();
+		$matches = array();
+		$destBuf = $srcBuf;
+		
+		if (preg_match_all('#<jdoc:include\ type="([^"]+)" (.*)\/>#iU', $srcBuf, $matches)){
+			$count = count($matches[1]);
+			for($i = 0; $i < $count; $i++)
+			{
+				$contents = '';
+				$type  = $matches[1][$i];
+				if (strcasecmp($type, 'head') == 0){		// ヘッダ埋め込みタグの場合
+					ob_clean();
+					$this->getHeader();
+					$contents = ob_get_contents();
+				} else if (strcasecmp($type, 'modules') == 0){		// ポジションタグの場合
+					$name = '';			// ポジション名
+					$style = '';		// 表示スタイル
+					$params = explode(' ', $matches[2][$i]);
+					for ($j = 0; $j < count($params); $j++){
+						list($key, $value) = explode('=', $params[$j]);
+						if (strcasecmp($key, 'name') == 0){
+							$name = trim($value, "\"'");
+						} else if (strcasecmp($key, 'style') == 0){
+							$style = trim($value, "\"'");
+						}
+					}
+					if (!empty($name)){		// ポジション名が取得できたとき
+						if (empty($style)) $style = 'none';
+						
+						// ウィジェットの出力を取得
+						$contents = $this->getContents($name, $style, false);
+					}
+				} else if (strcasecmp($type, 'component') == 0){	// メインポジションタグの場合
+					$contents = $this->getContents('main', 'none', false);
+				} else if (strcasecmp($type, 'message') == 0){	// メッセージタグの場合
+				}
+				$replace[$i] = $contents;
+			}
+			ob_clean();
+			$destBuf = str_replace($matches[0], $replace, $srcBuf);
+		}
+		return $destBuf;
+	}
 	/**
 	 * 遅延ウィジェット実行
 	 *
@@ -1131,7 +1190,7 @@ class PageManager extends Core
 		$cmd = $gRequestManager->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
 			
 		// ######### 携帯用サイトの場合は別にヘッダを作成する #########
-		if ($gEnvManager->getIsMobile()){
+		if ($gEnvManager->getIsMobileSite()){
 			// キャラクターセット
 			echo '<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS" />' . M3_NL;
 		
@@ -1210,7 +1269,7 @@ class PageManager extends Core
 		}
 		
 		// ##### PC用URLと携帯用URLのアクセス別に処理 #####
-		if ($gEnvManager->getIsMobile()){		// 携帯用URLのとき
+		if ($gEnvManager->getIsMobileSite()){		// 携帯用URLのとき
 		} else {			// PC用URLのとき
 			// 検索ロボットへの指示
 			$robots = htmlspecialchars(trim($this->db->getSiteDefValue(M3_TB_FIELD_SITE_ROBOTS)));
@@ -1458,9 +1517,11 @@ class PageManager extends Core
 	 * 各部品のHTML出力
 	 *
 	 * @param string $position		HTMLテンプレート上の書き出し位置
-	 * @param int    $style			0=ウィジェットを縦に並べる場合, 1=ウィジェットを横に並べる場合, -1=no wrapper
+	 * @param int    $style			ウィジェットの表示スタイル(Joomla!v1.5テンプレート用)
+	 * @param bool   $echo			echo出力するかどうか
+	 * @return string				出力コンテンツ
 	 */
-	function getContents($position, $style = 0)
+	function getContents($position, $style = '', $echo = true)
 	{
 		global $gRequestManager;
 		global $gEnvManager;
@@ -1471,7 +1532,8 @@ class PageManager extends Core
 		$subId		= $gEnvManager->getCurrentPageSubId();
 		if (empty($subId)) $subId = $gEnvManager->getDefaultPageSubId();
 
-		// ポジション名を表示
+		// ポジション名表示モードに応じて出力を作成
+		$contents = '';		// 出力コンテンツ
 		switch ($this->showPositionMode){
 			case 0:		// 通常画面
 				// ページ定義を取得。同じポジションが続く場合は最初の一度だけ定義を取得
@@ -1487,9 +1549,27 @@ class PageManager extends Core
 				}
 				// ウィジェットを実行
 				$count = count($this->pageDefRows);
-				for ($i = 0; $i < $count; $i++){
-					$ret = $this->pageDefLoop($i, $this->pageDefRows[$i]);
-					if (!$ret) return;		// 処理中断のときは終了
+				
+				if ($echo){			// echo出力のとき
+					for ($i = 0; $i < $count; $i++){
+						$ret = $this->pageDefLoop($i, $this->pageDefRows[$i]);
+						if (!$ret) return;		// 処理中断のときは終了
+					}
+				} else {
+					for ($i = 0; $i < $count; $i++){
+						ob_clean();
+						$ret = $this->pageDefLoop($i, $this->pageDefRows[$i]);
+						$widgetContent = ob_get_contents();
+
+						// Joomla!ウィジェットの出力に埋め込む
+						if (strcasecmp($style, 'none') == 0){
+							$contents .= $widgetContent;
+						} else {
+							$title = $this->pageDefRows[$i]['pd_title'];
+							$contents .= JModuleRender::getModuleContents($style, $widgetContent, $title);
+						}
+						if (!$ret) return;		// 処理中断のときは終了
+					}
 				}
 			
 				if ($position == 'main'){		// メイン部のときは、メッセージを出力
@@ -1502,9 +1582,9 @@ class PageManager extends Core
 				}
 				break;
 			case 1:		// ポジション表示
-				echo '<div style="background-color:#eee;margin:2px;padding:10px;border:3px solid #f00;color:#700;">ポジション名: ';
-				echo '<b>' . $position . '</b>';
-				echo '</div>';
+				$contents .= '<div style="background-color:#eee;margin:2px;padding:10px;border:3px solid #f00;color:#700;">ポジション名: ';
+				$contents .= '<b>' . $position . '</b>';
+				$contents .= '</div>';
 				break;
 			case 2:		// ポジション表示(ウィジェット付き)
 				$rev = '555';			// データのリビジョン番号
@@ -1530,21 +1610,28 @@ class PageManager extends Core
 						$this->pageDefPosition = '';
 					}
 				}
-				echo '<div id="' . $viewPosId . '" class="m3_widgetpos_box" m3="pos:' . $position . ';rev:' . $rev . ';">' . M3_NL;		// リビジョン番号を付加
-				echo '<h2>' . $position . '</h2>' . M3_NL;
+				$contents .= '<div id="' . $viewPosId . '" class="m3_widgetpos_box" m3="pos:' . $position . ';rev:' . $rev . ';">' . M3_NL;		// リビジョン番号を付加
+				$contents .= '<h2>' . $position . '</h2>' . M3_NL;
 				
 				// ウィジェットイメージを表示
 				$widgetTagHead = self::WIDGET_TAG_HEAD . $posId;
-				$this->echoWidgetList($widgetTagHead, $this->pageDefRows);
+				$contents .= $this->getWidgetList($widgetTagHead, $this->pageDefRows);
 
-				echo '</div>' . M3_NL;
+				$contents .= '</div>' . M3_NL;
 				break;
 			default:
-				echo '<div style="background-color:#eee;margin:2px;padding:10px;border:1px solid #f00;color:#700;">param error</div>';
+				$contents .= '<div style="background-color:#eee;margin:2px;padding:10px;border:1px solid #f00;color:#700;">param error</div>';
 				break;
 		}
 		// ポジションを保存
 		$this->viewPositions[] = $position;
+		
+		if ($echo){
+			echo $contents;
+			return '';
+		} else {
+			return $contents;
+		}
 	}
 	/**
 	 * 各部品のHTML出力
@@ -1714,14 +1801,14 @@ class PageManager extends Core
 					echo '<h2>' . $position2 . '</h2>' . M3_NL;
 				
 					// ウィジェット一覧出力
-					$this->echoWidgetList($widgetTagHead, $rows2);
+					echo $this->getWidgetList($widgetTagHead, $rows2);
 				} else {
 					// ウィジェット一覧外枠
 					echo '<div id="' . $updatepos[$i] . '" class="m3_widgetpos_box" m3="pos:' . $position . ';rev:' . $rev . ';">' . M3_NL;		// リビジョン番号を付加
 					echo '<h2>' . $position . '</h2>' . M3_NL;
 				
 					// ウィジェット一覧出力
-					$this->echoWidgetList($widgetTagHead, $rows);
+					echo $this->getWidgetList($widgetTagHead, $rows);
 				}
 				// ウィジェット一覧外枠
 				echo '</div>' . M3_NL;
@@ -1734,12 +1821,14 @@ class PageManager extends Core
 	 *
 	 * @param string $widgetTagHead		HTMLウィジェットID用のヘッダ
 	 * @param array $rows				ウィジェット一覧データ
+	 * @return string					ウィジェット一覧出力
 	 */
-	function echoWidgetList($widgetTagHead, $rows)
+	function getWidgetList($widgetTagHead, $rows)
 	{
 		global $gDesignManager;
 		global $gEnvManager;
 		
+		$contents = '';		// ウィジェット一覧出力コンテンツ
 		for ($i = 0; $i < count($rows); $i++){
 			$widgetId = $rows[$i]['wd_id'];
 			$desc = $rows[$i]['wd_description'];
@@ -1776,12 +1865,13 @@ class PageManager extends Core
 				$sharedClassName = 'm3_widget_shared';			// 共通ウィジェットのクラス
 			}
 			$m3Option = 'm3="widgetid:' . $widgetId . '; serial:' . $serial . '; configid:' . $configId . '; useconfig:' . $hasAdmin . '; shared:' . $shared . '"';
-			echo '<dl class="m3_widget_sortable" id="' . $widgetTag . '" ' . $m3Option . ' >' . M3_NL;
-			echo '<dt class="m3_widget_with_check_box ' . $sharedClassName . '">' . $rows[$i]['wd_name'] . '</dt>' . M3_NL;
-			echo '<dd><table width="100%"><tr valign="top"><td width="35">' . $imageTag . '</td><td>' . $desc . '</td></tr><table>' . M3_NL;
-			echo '<table width="100%"><tr><td>' . $configName . '</td><td align="right">' . $configImg . $widgetIndex . '</td></tr></table></dd>' . M3_NL;
-			echo '</dl>' . M3_NL;
+			$contents .= '<dl class="m3_widget_sortable" id="' . $widgetTag . '" ' . $m3Option . ' >' . M3_NL;
+			$contents .= '<dt class="m3_widget_with_check_box ' . $sharedClassName . '">' . $rows[$i]['wd_name'] . '</dt>' . M3_NL;
+			$contents .= '<dd><table width="100%"><tr valign="top"><td width="35">' . $imageTag . '</td><td>' . $desc . '</td></tr><table>' . M3_NL;
+			$contents .= '<table width="100%"><tr><td>' . $configName . '</td><td align="right">' . $configImg . $widgetIndex . '</td></tr></table></dd>' . M3_NL;
+			$contents .= '</dl>' . M3_NL;
 		}
+		return $contents;
 	}
 	/**
 	 * 取得した画面定義情報を処理
