@@ -10,9 +10,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: mosDef.php 515 2008-04-19 08:29:01Z fishbone $
+ * @version    SVN: $Id: mosDef.php 1752 2009-04-18 06:50:09Z fishbone $
  * @link       http://www.magic3.org
  */
 // Joomla用定義
@@ -35,6 +35,25 @@ class mosMainFrame {
 		global $cur_template;
 		return $cur_template;
 	}
+	// ##### 以下、Joomla!v1.5用に追加 #####
+	function getMessageQueue()
+	{
+		return array();
+	}
+	function getCfg($name)
+	{
+		global $gEnvManager;
+		
+		$value = '';
+		if (strcasecmp($name, 'sitename') == 0){
+			$value = $gEnvManager->getSiteName();// サイト名称
+		}
+		return $value;
+	}
+	/*function get($name)
+	{
+		return '';
+	}*/
 }
 $mainframe = new mosMainFrame();
 ?>
