@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_base.sql 1486 2009-01-30 04:14:53Z fishbone $
+-- * @version    SVN: $Id: create_base.sql 1760 2009-04-20 01:03:02Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -333,6 +333,7 @@ CREATE TABLE _templates (
     tm_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     tm_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレートID
     tm_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    tm_type              INT            DEFAULT 0                     NOT NULL,      -- テンプレート種別(0=デフォルトテンプレート(Joomla!v1.0)、1=Joomla!v1.5)
     tm_language          TEXT                                         NOT NULL,      -- 対応言語ID(「,」区切りで複数指定可)
     tm_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- テンプレート名
     tm_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
@@ -531,6 +532,7 @@ CREATE TABLE _page_def (
     pd_config_id         INT            DEFAULT 0                     NOT NULL,      -- ウィジェット定義ID
     pd_config_name       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ウィジェット定義名
     pd_suffix            VARCHAR(5)     DEFAULT ''                    NOT NULL,      -- インスタンスを区別するためのサフィックス文字列
+    pd_title             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- タイトル
     pd_style             TEXT                                         NOT NULL,      -- HTMLスタイル属性
     pd_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- ウィジェットを表示するかどうか
     pd_editable          BOOLEAN        DEFAULT true                  NOT NULL,      -- データ編集可能かどうか
