@@ -7,13 +7,13 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ja.js 758 2008-06-17 06:45:02Z fishbone $
+ * @version    SVN: $Id: ja.js 770 2008-06-19 07:49:38Z fishbone $
  * @link       http://www.magic3.org
  */
 FCKLang.EmojiEdit		            = "絵文字編集";
 FCKLang.EmojiInsert		            = "絵文字挿入";
 FCKLang.EmojiInsertLbl		        = "絵文字";
-FCKLang.EmojiDlgTitle		        = "絵文字挿入";
-FCKLang.EmojiDlgAllTab		        = "全て";
-FCKLang.EmojiDlgStdTab              = "基本絵文字";
-FCKLang.EmojiDlgExtTab              = "拡張絵文字";
+FCKLang.EmojiDlgTitle		        = "絵文字挿入/編集";
+FCKLang.DlgPreviewImage				= "プレビュー";
+FCKLang.DlgSelectImage				= "選択絵文字";
+FCKLang.EmojiBtn		            = "絵文字挿入/編集";
