@@ -18,10 +18,10 @@ function m3UpdateParentWindow()
 	window.opener.location.href = window.opener.location.href;
 }
 // 設定ウィンドウから親ウィンドウを更新
-function m3UpdateParentWindowByConfig()
+function m3UpdateParentWindowByConfig(serial)
 {
 	if (window.opener){
-		window.opener.location.href = window.opener.location.href;
+		if (window.opener.m3UpdateByConfig) window.opener.m3UpdateByConfig(serial);
 		if (window.opener.parent.m3UpdateByChildWindow) window.opener.parent.m3UpdateByChildWindow();
 	}
 }
