@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 1554 2009-03-05 05:05:27Z fishbone $
+ * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 1757 2009-04-19 08:46:04Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -75,6 +75,7 @@ class admin_mainAdjustwidgetWidgetContainer extends BaseWidgetContainer
 		$marginBottom = $request->trimValueOf('item_bottom');			// 下マージン
 		$marginLeft = $request->trimValueOf('item_left');			// 左マージン
 		$marginRight = $request->trimValueOf('item_right');			// 右マージン
+		$title = $request->trimValueOf('item_title');			// タイトル名
 		$act = $request->trimValueOf('act');
 		
 		$replaceNew = false;		// データを再取得するかどうか
@@ -95,7 +96,7 @@ class admin_mainAdjustwidgetWidgetContainer extends BaseWidgetContainer
 				if (!empty($marginLeft)) $style .= 'padding-left:' . $marginLeft . 'px;';
 				if (!empty($marginRight)) $style .= 'padding-right:' . $marginRight . 'px;';
 				
-				$ret = $this->db->updatePageDefStyle($defSerial, $style);
+				$ret = $this->db->updatePageDefInfo($defSerial, $style, $title);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 					$replaceNew = true;			// データを再取得
@@ -110,6 +111,7 @@ class admin_mainAdjustwidgetWidgetContainer extends BaseWidgetContainer
 			$marginBottom = '';			// 下マージン
 			$marginLeft = '';			// 左マージン
 			$marginRight = '';			// 右マージン
+			$title = '';			// タイトル名
 			$replaceNew = true;
 		}
 		// 表示データ再取得
@@ -142,6 +144,7 @@ class admin_mainAdjustwidgetWidgetContainer extends BaseWidgetContainer
 						}
 					}
 				}
+				$title = $row['pd_title'];			// タイトル名
 			}
 		}
 		
@@ -152,6 +155,7 @@ class admin_mainAdjustwidgetWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "bottom", $marginBottom);		// 下マージン
 		$this->tmpl->addVar("_widget", "left", $marginLeft);			// 左マージン
 		$this->tmpl->addVar("_widget", "right", $marginRight);			// 右マージン
+		$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));				// タイトル名
 		
 		// ページ定義IDとページ定義のレコードシリアル番号を更新
 		$this->endPageDefParam($defSerial, $defConfigId, $this->paramObj);
