@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 1205 2008-11-14 06:47:47Z fishbone $
+ * @version    SVN: $Id: admin_mainPagedefWidgetContainer.php 1742 2009-04-16 08:40:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -133,7 +133,7 @@ class admin_mainPagedefWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->addVar("_widget", "TMPL_IMAGE", $imagePath);							// プレビュー画像
 			
 			// テンプレート選択メニュー作成
-			$this->db->getAllMobileTemplateList(array($this, 'templateIdLoop'));
+			$this->db->getAllTemplateList(1/* 携帯用 */, array($this, 'templateIdLoop'));
 		
 			// ウィジェットリストを取得
 		//	$this->db->getAvailableMobileWidgetList(array($this, 'widgetListLoop'));
@@ -147,7 +147,7 @@ class admin_mainPagedefWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->addVar("_widget", "TMPL_IMAGE", $imagePath);							// プレビュー画像
 			
 			// テンプレート選択メニュー作成
-			$this->db->getAllTemplateList(array($this, 'templateIdLoop'));
+			$this->db->getAllTemplateList(0/* PC用 */, array($this, 'templateIdLoop'));
 		
 			// ウィジェットリストを取得
 		//	$this->db->getAvailableWidgetList(array($this, 'widgetListLoop'));
