@@ -8,14 +8,15 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 1187 2008-11-07 09:54:10Z fishbone $
+ * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 1755 2009-04-18 12:53:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 require_once($gEnvManager->getLibPath()				. '/pcl/pclzip.lib.php' );
+require_once($gEnvManager->getCurrentWidgetContainerPath()		. '/admin_mainDef.php');			// 定義クラス
 			
 class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 {
@@ -23,25 +24,31 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 	private $sysDb;		// システムDBオブジェクト
 	private $newTemplate = array();		// 新規追加テンプレート
 	private $defalutTemplate;	// デフォルトのテンプレート
+	private $templateTypeArray;		// テンプレートタイプ
+	private $templateType;			// 現在のテンプレートタイプ
+	private $showDetail;			// 詳細表示するかどうか
 	const TEMPLATE_THUMBNAIL_FILENAME = 'template_thumbnail.png';		// テンプレートサムネール
 	const previewImageSizeHeight = 27;
 	const previewImageSizeWidth = 42;
 	const imageSizeHeight = 135;
 	const imageSizeWidth = 210;
+	const JOOMLA_CONFIG_FILENAME = 'templateDetails.xml';		// Joomla!のテンプレート設定ファイル名
 		
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-				
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DB接続オブジェクト作成
 		$this->db = new admin_mainDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
+		
+		// テンプレートタイプメニュー項目
+		$this->templateTypeArray = array(	array(	'name' => 'PC用',		'value' => '0'),
+											array(	'name' => '携帯用',		'value' => '1'));
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -55,11 +62,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{	
-		if ($this->db->canDetailConfig()){		// 詳細設定可能なとき
-			return 'templist.tmpl.html';
-		} else {
-			return 'templist_simple.tmpl.html';
-		}
+		return 'templist.tmpl.html';
 	}
 	/**
 	 * テンプレートにデータ埋め込む
@@ -72,20 +75,25 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gSystemManager;
-
 		$act = $request->trimValueOf('act');
 		$selectedItemNo = $request->trimValueOf('no');		// 処理対象の項目番号
-		$userId = $gEnvManager->getCurrentUserId();
+		$userId = $this->gEnv->getCurrentUserId();
 		$templateId = $request->trimValueOf('template');		// テンプレートID
-
+		$this->templateType = $request->trimValueOf('item_type');// 現在のテンプレートタイプ
+		if ($this->templateType == '') $this->templateType = '0';		// デフォルトの項目タイプは通常リンク
+		$this->showDetail = ($request->trimValueOf('item_show_detail') == 'on') ? 1 : 0;		// 詳細表示するかどうか
+		
 		if ($act == 'readnew'){		// テンプレート再読み込みのとき
 			$addTemplateCount = 0;
 			// テンプレート一覧取得
 			if ($this->db->getAllTemplateIdList($rows)){
 				// テンプレートディレクトリチェック
-				$searchPath = $gEnvManager->getTemplatesPath();
+				if ($this->templateType == '0'){		// PC用テンプレート
+					$searchPath = $this->gEnv->getTemplatesPath();
+				} else {		// 携帯用テンプレート
+					$searchPath = $this->gEnv->getTemplatesPath() . '/' . M3_DIR_NAME_MOBILE;
+				}
+				
 				if (is_dir($searchPath)){
 					$dir = dir($searchPath);
 					while (($file = $dir->read()) !== false){
@@ -93,15 +101,24 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 						// ディレクトリかどうかチェック
 						if (strncmp($file, '.', 1) != 0 && $file != '..' && is_dir($filePath)
 							&& strncmp($file, '_', 1) != 0		// 「_」で始まる名前のディレクトリは読み込まない
-							&& strcmp($file, 'm') != 0){		// 携帯用のディレクトリ「m」は読み込まない
+							&& strcmp($file, M3_DIR_NAME_MOBILE) != 0){		// 携帯用のディレクトリ「m」は読み込まない
+							
+							// テンプレートIDを作成
+							if ($this->templateType == '0'){		// PC用テンプレート
+								$templateId = $file;
+							} else {		// 携帯用テンプレート
+								$templateId = M3_DIR_NAME_MOBILE . '/' . $file;
+							}
+				
 							// DBに登録されていない場合は登録
 							for ($i = 0; $i < count($rows); $i++){
-								if ($file == $rows[$i]['tm_id']) break;
+								if ($templateId == $rows[$i]['tm_id']) break;
 							}
 							if ($i == count($rows)){
-								$ret = $this->db->addNewTemplate($file, $file, $userId);
+								// テンプレートを新規登録
+								$ret = $this->addNewTemplate(intval($this->templateType), $templateId);
 								if ($ret){
-									$this->newTemplate[] = $file;
+									$this->newTemplate[] = $templateId;
 									$addTemplateCount++;		// テンプレート追加
 								}
 							}
@@ -139,7 +156,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			
 			if (!$this->isExistsMsg()){		// エラーなしのとき
 				// テンプレートディレクトリ取得
-				$templatePath = $gEnvManager->getTemplatesPath() . '/' . $templateId;
+				$templatePath = $this->gEnv->getTemplatesPath() . '/' . $templateId;
 		
 				// ディレクトリ削除
 				if ((is_dir($templatePath) && rmDirectory($templatePath)) || !is_dir($templatePath)){// 削除成功か、ディレクトリが存在しないとき
@@ -155,13 +172,18 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			}
 		} else if ($act == 'upload'){		// ファイルアップロードの場合
 			// アップロードされたファイルか？セキュリティチェックする
-			if (is_uploaded_file($_FILES['upfile']['tmp_name'])) {
+			if (is_uploaded_file($_FILES['upfile']['tmp_name'])){
 				$uploadFilename = $_FILES['upfile']['name'];		// アップロードされたファイルのファイル名取得
 
 				// ファイル名の解析
 				$pathParts = pathinfo($uploadFilename);
 				$ext = $pathParts['extension'];		// 拡張子
 				$templateName = basename($uploadFilename, '.' . $ext);		// 拡張子をはずす
+				if ($this->templateType == '0'){		// PC用テンプレート
+					$templateId = $templateName;
+				} else {		// 携帯用テンプレート
+					$templateId = M3_DIR_NAME_MOBILE . '/' . $templateName;
+				}
 				
 				// ファイル拡張子のチェック
 				if ($ext != 'zip'){
@@ -170,26 +192,30 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 				}
 				
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
-					// 同名のテンプレートがないかチェック
+					// 同IDのテンプレートがないかチェック
 					if ($this->db->getAllTemplateIdList($rows)){
 						for ($i = 0; $i < count($rows); $i++){
-							if ($templateName == $rows[$i]['tm_id']) break;
+							if ($templateId == $rows[$i]['tm_id']) break;
 						}
 						if ($i < count($rows)){
-							$msg = '同名のテンプレートがすでに存在します(テンプレート名：' . $templateName . ')';
+							$msg = '同じIDのテンプレートがすでに存在します(テンプレートID：' . $templateId . ')';
 							$this->setAppErrorMsg($msg);
 						}
 					}
 				}
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
 					// ファイルを保存するサーバディレクトリを指定
-					$tmpFile = tempnam($gEnvManager->getWorkDirPath(), M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
+					$tmpFile = tempnam($this->gEnv->getWorkDirPath(), M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
 		
 					// アップされたテンポラリファイルを保存ディレクトリにコピー
 					$ret = move_uploaded_file($_FILES['upfile']['tmp_name'], $tmpFile);
 					if ($ret){
 						// 解凍先ディレクトリ
-						$extDir = $gEnvManager->getTemplatesPath();
+						if ($this->templateType == '0'){		// PC用テンプレート
+							$extDir = $this->gEnv->getTemplatesPath();
+						} else {		// 携帯用テンプレート
+							$extDir = $this->gEnv->getTemplatesPath() . '/' . M3_DIR_NAME_MOBILE;
+						}
 					
 						// zipファイルを解凍
 						$zipFile = new PclZip($tmpFile);
@@ -209,11 +235,12 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 							if (strncmp($zipList[0]['filename'], $cmpTemplateName, strlen($cmpTemplateName)) == 0){			// bugfix 先頭は必ずしもルートディレクトリ名ではない
 								$ret = $zipFile->extract(PCLZIP_OPT_PATH, $extDir);
 								if ($ret){
-									$ret = $this->db->addNewTemplate($templateName, $templateName, $userId);
+									// テンプレートを新規登録
+									$ret = $this->addNewTemplate(intval($this->templateType), $templateId);
 								
-									$msg = 'ファイルのアップロードが完了しました(テンプレート名：' . $templateName . ')';
+									$msg = 'ファイルのアップロードが完了しました(テンプレートID：' . $templateId . ')';
 									$this->setGuidanceMsg($msg);
-									$this->newTemplate[] = $templateName;
+									$this->newTemplate[] = $templateId;
 								} else {
 									$msg = 'ファイルのアップロードに失敗しました(要因: ' . $zipFile->errorName(true) . ')';
 									$this->setAppErrorMsg($msg);
@@ -231,14 +258,21 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 					unlink($tmpFile);
 				}
 			} else {
-				$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $gSystemManager->getMaxFileSizeForUpload() . 'バイト)';
+				$msg = 'アップロードファイルが見つかりません(要因：アップロード可能なファイルのMaxサイズを超えている可能性があります - ' . $this->gSystem->getMaxFileSizeForUpload() . 'バイト)';
 				$this->setAppErrorMsg($msg);
 			}
 		} else if ($act == 'download'){		// ファイルダウンロードのとき
-			$templatesDir = $gEnvManager->getTemplatesPath();		// テンプレートディレクトリ
-			$templateDir = $templatesDir . '/' . $templateId;			// ダウンロードするウィジェットのディレクトリ
-			$downloadFilename = $templateId . '.zip';		// ダウンロード時のファイル名
-			$tmpFile = tempnam($gEnvManager->getWorkDirPath(), M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
+			if ($this->templateType == '0'){		// PC用テンプレート
+				$templatesDir = $this->gEnv->getTemplatesPath();		// テンプレートディレクトリ
+				$templateDir = $templatesDir . '/' . $templateId;			// ダウンロードするウィジェットのディレクトリ
+				$downloadFilename = $templateId . '.zip';		// ダウンロード時のファイル名
+			} else {		// 携帯用テンプレート
+				$templatesDir = $this->gEnv->getTemplatesPath() . '/' . M3_DIR_NAME_MOBILE;		// テンプレートディレクトリ
+				$templateDir = $this->gEnv->getTemplatesPath() . '/' . $templateId;			// ダウンロードするウィジェットのディレクトリ
+				list($dir, $filename) = explode('/', $templateId);	// 先頭の「m/」を削除
+				$downloadFilename = $filename . '.zip';		// ダウンロード時のファイル名
+			}
+			$tmpFile = tempnam($this->gEnv->getWorkDirPath(), M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
 			
 			// zip圧縮
 			$zipFile = new PclZip($tmpFile);
@@ -268,21 +302,52 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			if (empty($templateId)) $this->setMsg(self::MSG_APP_ERR, 'テンプレートIDが指定されていません');
 			
 			if (!$this->isExistsMsg()){		// エラーなしのとき
-				// デフォルトテンプレート変更
-				$this->db->changeDefaultTemplate($templateId);
+				if ($this->templateType == '0'){		// PC用テンプレートのとき
+					// デフォルトテンプレート変更
+					$this->db->changeDefaultTemplate($templateId);
 
-				// セッションのテンプレートIDを更新
-				$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
+					// セッションのテンプレートIDを更新
+					$request->setSessionValue(M3_SESSION_CURRENT_TEMPLATE, $templateId);
+				} else {			// 携帯用テンプレートのとき
+					// デフォルトテンプレート変更
+					$this->db->changeDefaultMobileTemplate($templateId);
+				}
 			}
+		} else if ($act == 'changedetail'){		// 詳細表示の変更のとき
+			// 画面設定値を更新
+			$this->gDisp->setAdminConfig(admin_mainDef::CFG_SHOW_TEMPLATE_DETAIL, strval($this->showDetail));
+		} else if ($act == 'changetype'){		// テンプレートタイプの変更のとき
 		}
-		$this->defalutTemplate = $this->sysDb->getDefaultTemplateId();// デフォルトのテンプレート
-				
-		// パラメータを設定
-		$this->tmpl->addVar("_widget", "install_dir", $gEnvManager->getTemplatesPath());// インストールディレクトリ
-		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());// 管理用URL
+		// 詳細設定状況を再取得
+		$this->showDetail = intval($this->gDisp->getAdminConfig(admin_mainDef::CFG_SHOW_TEMPLATE_DETAIL));
+			
+		// テンプレートのタイプごとの処理
+		if ($this->templateType == '0'){		// PC用テンプレート
+			$this->defalutTemplate = $this->sysDb->getDefaultTemplateId();// デフォルトのテンプレート
+			$installDir = $this->gEnv->getTemplatesPath();// テンプレート格納ディレクトリ
+		} else {			// 携帯用テンプレート
+			$this->defalutTemplate = $this->sysDb->getDefaultMobileTemplateId();// デフォルトのテンプレート
+			$installDir = $this->gEnv->getTemplatesPath() . '/' . M3_DIR_NAME_MOBILE;// テンプレート格納ディレクトリ
+		}
+		
+		// 表示制御
+		if (!empty($this->showDetail)){		// 詳細表示のとき
+			$this->tmpl->setAttribute('show_dir', 'visibility', 'visible');// ディレクトリ表示
+			$this->tmpl->setAttribute('show_format', 'visibility', 'visible');// テンプレート形式
+		}
+		
+		// テンプレート選択メニュー作成
+		$this->createTemplateTypeMenu();
+		
+		// 画面にデータを埋め込む
+		$checkedStr = '';
+		if (!empty($this->showDetail)) $checkedStr = 'checked';
+		$this->tmpl->addVar("_widget", "show_detail", $checkedStr);		// 詳細表示
+		$this->tmpl->addVar("show_dir", "install_dir", $installDir);// インストールディレクトリ
+		$this->tmpl->addVar("_widget", "admin_url", $this->gEnv->getDefaultAdminUrl());// 管理用URL
 				
 		// テンプレートリストを取得
-		$this->db->getAllTemplateList(array($this, 'tempListLoop'));
+		$this->db->getAllTemplateList(intval($this->templateType), array($this, 'tempListLoop'));
 	}
 	/**
 	 * テンプレートリスト、取得したデータをテンプレートに設定する
@@ -294,8 +359,11 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 	 */
 	function tempListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-				
+		// 詳細表示の設定
+		if ($this->showDetail){
+			$this->tmpl->addVar('templist', 'templatetype', 'detail');		// 詳細表示
+		}
+
 		// デフォルトテンプレート
 		$defaultButton = '';
 		if ($fetchedRow['tm_id'] == $this->defalutTemplate){
@@ -305,22 +373,8 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 		// 画面イメージ表示設定
 		$id = $this->convertToDispString($fetchedRow['tm_id']);				// テンプレートID
 		$name = $this->convertToDispString($fetchedRow['tm_name']);			// テンプレート名
-		$imgUrl = $gEnvManager->getTemplatesUrl() . '/' . $id . '/' . self::TEMPLATE_THUMBNAIL_FILENAME;
+		$imgUrl = $this->gEnv->getTemplatesUrl() . '/' . $id . '/' . self::TEMPLATE_THUMBNAIL_FILENAME;
 		
-		/*
-		$hasCss = '';
-		if ($fetchedRow['wd_read_css']){
-			$hasCss = 'checked';
-		}
-		// 編集不可項目のときは、ボタンを使用不可にする
-		$buttonEnabled = '';
-		if (!$fetchedRow['wd_editable']) $buttonEnabled = 'disabled';
-		*/
-		// 行カラーの設定
-	/*	$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}*/
 		// 新規に追加されたテンプレートかチェック
 		$idText = $id;
 		for ($i = 0; $i < count($this->newTemplate); $i++){
@@ -329,16 +383,24 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 				break;
 			}
 		}
-		//$imageTag = '<a class="thumbnail" href="#"><img src="' . $imgUrl . '" width="' . self::previewImageSizeWidth . '" height="' . self::previewImageSizeHeight . '" border="0" /><span><img src="' . $imgUrl . '" width="' . self::imageSizeWidth . '" height="' . self::imageSizeHeight . '"/></span></a>';
+		// テンプレートサムネール画像
 		$imageTag = '<img src="' . $imgUrl . '" width="' . self::previewImageSizeWidth . '" height="' . self::previewImageSizeHeight . '" border="0" />';
+		
+		// テンプレートフォーマット
+		$formatType = '未定';
+		if ($fetchedRow['tm_type'] == 0){		// Joomla!v1.0型
+			$formatType = 'J10';		// テンプレート形式
+		} else if ($fetchedRow['tm_type'] == 1){	// Joomla!v1.5型
+			$formatType = 'J15';		// テンプレート形式
+		}
+		
 		$row = array(
-			//'line_color' => $lineColor,											// 行のカラー
 			'no' => $index + 1,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['tm_serial']),			// シリアル番号
-			//'id_with_image' => $idSpan,			// 画像付きID
-			'id_with_image' => $id,
+			'id_str' => $idText,
 			'id' => $id,			// ID
 			'name' => $name,		// 名前
+			'format_type' => $formatType,		// テンプレート形式
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['tm_create_dt']),	// 更新日時
 			'is_default' => $defaultButton,										// デフォルトテンプレートかどうか
 			'image_tag' => $imageTag		// 画像
@@ -347,5 +409,64 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->parseTemplate('templist', 'a');
 		return true;
 	}
+	/**
+	 * テンプレートを新規追加
+	 *
+	 * @param int $type			テンプレート種別(0=PC用、1=携帯用)
+	 * @param string $id		テンプレートID(ディレクトリ名)
+	 * @param bool				true=成功、false=失敗
+	 */
+	function addNewTemplate($type, $id)
+	{
+		$ret = false;
+		$templType = 0;			// テンプレートのタイプデフォルト値(Joomla!1.0)
+		
+		// テンプレートの種別を判定
+		if (empty($type)){		// PC用テンプレートの場合のみチェック
+			$configFile = $this->gEnv->getTemplatesPath() . '/' . $id . '/' . self::JOOMLA_CONFIG_FILENAME;
+			if (file_exists($configFile)){
+				if (!class_exists('DOMDocument')){
+					$msg = 'Dom処理用モジュールがインストールされていません';
+					$this->setAppErrorMsg($msg);
+					return false;
+				}
+				$doc = new DOMDocument();
+				$ret = $doc->load($configFile);
+				if ($ret){
+					$rootTag = $doc->getElementsByTagName('install');
+					if ($rootTag->length > 0){
+						if ($rootTag->item(0)->getAttribute('type') == 'template' && $rootTag->item(0)->getAttribute('version') == '1.5') $templType = 1;		// Joomla!v1.5テンプレートのとき
+					}
+				}
+			}
+		}
+		
+		// テンプレートを登録
+		$ret = $this->db->addNewTemplate($id, $id, $templType, intval($type));
+		return $ret;
+	}
+	/**
+	 * タイプ選択メニュー作成
+	 *
+	 * @return なし
+	 */
+	function createTemplateTypeMenu()
+	{
+		for ($i = 0; $i < count($this->templateTypeArray); $i++){
+			$value = $this->templateTypeArray[$i]['value'];
+			$name = $this->templateTypeArray[$i]['name'];
+			
+			$selected = '';
+			if ($value == $this->templateType) $selected = 'selected';
+			
+			$row = array(
+				'value'    => $value,			// ページID
+				'name'     => $name,			// ページ名
+				'selected' => $selected														// 選択中かどうか
+			);
+			$this->tmpl->addVars('item_type_list', $row);
+			$this->tmpl->parseTemplate('item_type_list', 'a');
+		}
+	}
 }
 ?>
