@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 1556 2009-03-06 04:42:03Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 1750 2009-04-18 06:49:28Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -887,9 +887,10 @@ class admin_mainDb extends BaseDb
 	 *
 	 * @param int $serialNo			シリアルNo
 	 * @param string $style			スタイル値
+	 * @param string $title			タイトル
 	 * @return						true=成功、false=失敗
 	 */
-	function updatePageDefStyle($serialNo, $style)
+	function updatePageDefInfo($serialNo, $style, $title)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$user = $this->gEnv->getCurrentUserId();	// 現在のユーザ
@@ -901,10 +902,11 @@ class admin_mainDb extends BaseDb
 		$queryStr  = 'UPDATE _page_def ';
 		$queryStr .=   'SET ';
 		$queryStr .=     'pd_style = ?, ';
+		$queryStr .=     'pd_title = ?, ';
 		$queryStr .=     'pd_update_user_id = ?, ';
 		$queryStr .=     'pd_update_dt = ? ';
 		$queryStr .=   'WHERE pd_serial = ? ';
-		$ret = $this->execStatement($queryStr, array($style, $user, $now, $serialNo));
+		$ret = $this->execStatement($queryStr, array($style, $title, $user, $now, $serialNo));
 
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1297,14 +1299,21 @@ class admin_mainDb extends BaseDb
 	/**
 	 * テンプレートリスト(携帯用以外)取得
 	 *
+	 * @param int      $type		テンプレートのタイプ(0=PC用、1=携帯用)
 	 * @param function $callback	コールバック関数
 	 * @return						なし
 	 */
-	function getAllTemplateList($callback)
+	function getAllTemplateList($type, $callback)
 	{
 		$queryStr = 'SELECT * FROM _templates ';
 		$queryStr .=  'WHERE tm_deleted = false ';// 削除されていない
-		$queryStr .=    'AND tm_mobile = false ';		// 携帯用以外
+		if ($type == 0){			// PC用のとき
+			$queryStr .=    'AND tm_mobile = false ';		// 携帯用以外
+		} else if ($type == 1){			// 携帯用のとき
+			$queryStr .=    'AND tm_mobile = true ';		// 携帯用
+		} else {			// その他
+			$queryStr .=    'AND tm_mobile = false ';		// 携帯用以外
+		}
 		$queryStr .=  'ORDER BY tm_id';
 		$this->selectLoop($queryStr, array(), $callback);
 	}
@@ -1314,14 +1323,14 @@ class admin_mainDb extends BaseDb
 	 * @param function $callback	コールバック関数
 	 * @return						なし
 	 */
-	function getAllMobileTemplateList($callback)
+	/*function getAllMobileTemplateList($callback)
 	{
 		$queryStr = 'SELECT * FROM _templates ';
 		$queryStr .=  'WHERE tm_deleted = false ';// 削除されていない
 		$queryStr .=    'AND tm_mobile = true ';		// 携帯用
 		$queryStr .=  'ORDER BY tm_id';
 		$this->selectLoop($queryStr, array(), $callback);
-	}
+	}*/
 	/**
 	 * テンプレートIDリスト取得
 	 *
@@ -1332,7 +1341,6 @@ class admin_mainDb extends BaseDb
 	{
 		$queryStr = 'SELECT * FROM _templates ';
 		$queryStr .=  'WHERE tm_deleted = false ';// 削除されていない
-		$queryStr .=  'AND tm_mobile = false ';// 携帯以外
 		$queryStr .=  'ORDER BY tm_id';
 		$retValue = $this->selectRecords($queryStr, array(), $rows);
 		return $retValue;
@@ -1357,11 +1365,13 @@ class admin_mainDb extends BaseDb
 	 *
 	 * @param string  $id			テンプレートID
 	 * @param string  $name			テンプレート名
-	 * @param int     $userId		更新者ユーザID
+	 * @param int     $type			テンプレートのタイプ
+	 * @param int     $mobile		携帯対応かどうか(0=PC用、1=携帯用)
 	 * @return						なし
 	 */
-	function addNewTemplate($id, $name, $userId)
+	function addNewTemplate($id, $name, $type, $mobile = 0)
 	{
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$historyIndex = 0;
 		
@@ -1369,10 +1379,9 @@ class admin_mainDb extends BaseDb
 		$this->startTransaction();
 		
 		// 同じIDが登録済みかどうかチェック
-		$queryStr = 'select * from _templates ';
-		$queryStr .=  'where tm_id = ? ';
-		$queryStr .=  'order by tm_history_index desc ';
-		$queryStr .=    'limit 1';
+		$queryStr = 'SELECT * FROM _templates ';
+		$queryStr .=  'WHERE tm_id = ? ';
+		$queryStr .=  'ORDER BY tm_history_index DESC ';
 		$ret = $this->selectRecord($queryStr, array($id), $row);
 		if ($ret){
 			if (!$row['tm_deleted']){		// レコードが削除されていなければ、削除
@@ -1388,10 +1397,10 @@ class admin_mainDb extends BaseDb
 		}
 		
 		$queryStr = 'INSERT INTO _templates ';
-		$queryStr .=  '(tm_id, tm_name, tm_history_index, tm_create_dt, tm_create_user_id) ';
+		$queryStr .=  '(tm_id, tm_history_index, tm_name, tm_type, tm_mobile, tm_create_dt, tm_create_user_id) ';
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, now(), ?)';
-		$this->execStatement($queryStr, array($id, $name, $historyIndex, $userId));
+		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?)';
+		$this->execStatement($queryStr, array($id, $historyIndex, $name, $type, $mobile, $now, $userId));
 		
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1406,10 +1415,8 @@ class admin_mainDb extends BaseDb
 	 */
 	function updateTemplate($templateId, $name)
 	{
-		global $gEnvManager;
-		
 		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
 				
 		// トランザクション開始
 		$this->startTransaction();
@@ -1444,6 +1451,9 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   'tm_id, ';
 		$queryStr .=   'tm_history_index, ';
 		$queryStr .=   'tm_name, ';
+		$queryStr .=   'tm_type, ';
+		$queryStr .=   'tm_mobile, ';
+		$queryStr .=   'tm_available, ';
 		$queryStr .=   'tm_create_user_id, ';
 		$queryStr .=   'tm_create_dt ';
 		$queryStr .= ') VALUES (';
@@ -1451,8 +1461,11 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
+		$queryStr .=   '?, ';
 		$queryStr .=   '?)';
-		$this->execStatement($queryStr, array($row['tm_id'], $historyIndex, $name, $userId, $now));
+		$this->execStatement($queryStr, array($row['tm_id'], $historyIndex, $name, $row['tm_type'], $row['tm_mobile'], $row['tm_available'], $userId, $now));
 
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1466,10 +1479,8 @@ class admin_mainDb extends BaseDb
 	 */
 	function deleteTemplate($templateId)
 	{
-		global $gEnvManager;
-		
 		$now = date("Y/m/d H:i:s");	// 現在日時
-		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
 		
 		// トランザクション開始
 		$this->startTransaction();
