@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2007 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_bannerWidgetContainer.php 174 2007-12-27 06:41:24Z fishbone $
+ * @version    SVN: $Id: admin_bannerWidgetContainer.php 1186 2008-11-07 06:27:19Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -22,8 +22,6 @@ class admin_bannerWidgetContainer extends BaseWidgetContainer
 	var $db;	// DB接続オブジェクト
 	var $serialNo;		// 選択中の項目のシリアル番号
 	var $bannerId;		// 選択中のバナーID
-//	var $bannerItemId;	// 選択中のバナー項目ID
-//	var $mode;			// 画面モード
 	var $dispIdArray;	// 表示中のバナー項目ID
 
 	/**
@@ -377,10 +375,10 @@ class admin_bannerWidgetContainer extends BaseWidgetContainer
 			// 入力チェック
 			$this->checkInput($name, '名前');
 			
-			if (!ValueCheck::isNumeric($imageWidth)){		// 数値かどうかのチェック
+			if (!empty($imageWidth) && !ValueCheck::isNumeric($imageWidth)){		// 数値かどうかのチェック
 				$this->setAppErrorMsg('画像の幅は数字で指定してください');
 			}
-			if (!ValueCheck::isNumeric($imageHeight)){		// 数値かどうかのチェック
+			if (!empty($imageHeight) && !ValueCheck::isNumeric($imageHeight)){		// 数値かどうかのチェック
 				$this->setAppErrorMsg('画像の高さは数字で指定してください');
 			}			
 			
