@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2007 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: bbs_login_boxWidgetContainer.php 2 2007-11-03 04:59:01Z fishbone $
+ * @version    SVN: $Id: bbs_login_boxWidgetContainer.php 1443 2009-01-15 09:22:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -115,7 +115,11 @@ class bbs_login_boxWidgetContainer extends BaseWidgetContainer
 		
 		// ログイン状態を取得
 		$userName = $gEnvManager->getCurrentUserName();
-		if (!empty($userName)) $this->tmpl->addVar("_widget", "user_name", 'ログインユーザ: ' . $userName . ' 様');
+		if (empty($userName)){
+			$this->tmpl->addVar("_widget", "user_name", '');
+		} else {
+			$this->tmpl->addVar("_widget", "user_name", 'ログインユーザ: ' . $userName . ' 様');
+		}
 		
 		// タイトル部のパラメータ
 		$this->tmpl->addVar("_widget", "default_menu_param", $gDesignManager->getDefaultWidgetTableParam());
