@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainConfigWidgetContainer.php 673 2008-06-01 13:02:15Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainConfigWidgetContainer.php 1453 2009-01-19 08:40:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_blog_mainBaseWidgetContainer.php');
@@ -23,6 +23,7 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 	const RECEIVE_TRACKBACK		= 'receive_trackback';		// トラックバックを受け付けるかどうか
 	const ENTRY_VIEW_COUNT		= 'entry_view_count';			// 記事表示数
 	const ENTRY_VIEW_ORDER		= 'entry_view_order';			// 記事表示方向
+	const DEFAULT_VIEW_COUNT	= 10;				// デフォルトの表示記事数
 	
 	/**
 	 * コンストラクタ
@@ -97,6 +98,7 @@ class admin_blog_mainConfigWidgetContainer extends admin_blog_mainBaseWidgetCont
 			}
 		} else {		// 初期表示の場合
 			$entryViewCount	= $this->db->getConfig(self::ENTRY_VIEW_COUNT);// 記事表示数
+			if (empty($entryViewCount)) $entryViewCount = self::DEFAULT_VIEW_COUNT;
 			$entryViewOrder	= $this->db->getConfig(self::ENTRY_VIEW_ORDER);// 記事表示順
 			$receiveComment	= $this->db->getConfig(self::RECEIVE_COMMENT);
 		}
