@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 852 2008-07-23 10:20:20Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 1448 2009-01-16 04:53:37Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_blog_mainBaseWidgetContainer.php');
@@ -217,7 +217,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		// デフォルト値
 		$defaultLangId	= $gEnvManager->getDefaultLanguage();
 		$regUserId		= $gEnvManager->getCurrentUserId();			// 記事投稿ユーザ
-		$regDt			= date("Y/m/d H:i:s");						// 投稿日時
+		//$regDt			= date("Y/m/d H:i:s");						// 投稿日時
 
 		$act = $request->trimValueOf('act');
 		$this->langId = $request->trimValueOf('item_lang');				// 現在メニューで選択中の言語
@@ -226,8 +226,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
 		if (empty($this->serialNo)) $this->serialNo = 0;
 		$name = $request->trimValueOf('item_name');
+		$entry_date = $request->trimValueOf('item_entry_date');		// 投稿日
+		$entry_time = $request->trimValueOf('item_entry_time');		// 投稿時間
 		$html = $request->valueOf('item_html');
 		$html2 = $request->valueOf('item_html2');
+		if (strlen($html2) <= 10){ // IE6のときFCKEditorのバグの対応(「続き」が空の場合でもpタグが送信される)
+			$html2 = '';
+		}
 		$status = $request->trimValueOf('item_status');		// エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
 		$category = '';									// カテゴリー
 		
@@ -262,7 +267,6 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				//$html = '';				// HTML
 				$status = 0;				// エントリー状況
 				$reg_user = '';				// 投稿者
-				$reg_dt = '';				// 投稿日時
 				$update_user = '';// 更新者
 				$update_dt = '';							
 			} else {
@@ -271,9 +275,12 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		} else if ($act == 'add' || $act == 'addlang'){		// 項目追加の場合
 			// 入力チェック
 			$this->checkInput($name, 'タイトル');
+			$this->checkDate($entry_date, '投稿日付');
+			$this->checkTime($entry_time, '投稿時間');
 					
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
+				$regDt = $this->convertToProperDate($entry_date) . ' ' . $this->convertToProperTime($entry_time);		// 投稿日時
 				if ($act == 'add'){
 					$ret = $this->db->addEntryItem(0, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $regUserId, $regDt, $newSerial);
 				} else {
@@ -291,10 +298,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		} else if ($act == 'update'){		// 項目更新の場合
 			// 入力チェック
 			$this->checkInput($name, 'タイトル');
+			$this->checkDate($entry_date, '投稿日付');
+			$this->checkTime($entry_time, '投稿時間');
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
-				$ret = $this->db->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, ''/*投稿者そのまま*/, ''/*投稿日時そのまま*/, $newSerial);
+				$regDt = $this->convertToProperDate($entry_date) . ' ' . $this->convertToProperTime($entry_time);		// 投稿日時
+				$ret = $this->db->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, ''/*投稿者そのまま*/, $regDt, $newSerial);
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
 					// シリアル番号更新
@@ -331,6 +341,10 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				}
 			}
 		} else {	// 初期画面表示のとき
+			// 初期値設定
+			$entry_date = date("Y/m/d");		// 投稿日
+			$entry_time = date("H:i:s");		// 投稿時間
+			
 			$dataReload = true;		// データの再ロード
 		}
 		
@@ -346,7 +360,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				$html2 = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $html2);// アプリケーションルートを変換
 				$status = $row['be_status'];				// エントリー状況
 				$reg_user = $row['reg_user_name'];				// 投稿者
-				$reg_dt = $this->convertToDispDateTime($row['be_regist_dt']);				// 投稿日時
+				$entry_date = $this->timestampToDate($row['be_regist_dt']);		// 投稿日
+				$entry_time = $this->timestampToTime($row['be_regist_dt']);		// 投稿時間
 				$update_user = $this->convertToDispString($row['lu_name']);// 更新者
 				$update_dt = $this->convertToDispDateTime($row['be_create_dt']);
 				
@@ -388,7 +403,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			//}
 		}
 		// ### 入力値を再設定 ###
-		$this->tmpl->addVar("_widget", "item_name", $name);		// 名前
+		$this->tmpl->addVar('_widget', 'entry', $this->entryId);
+		$this->tmpl->addVar("_widget", "item_name", $this->convertToDispString($name));		// 名前
 		$this->tmpl->addVar("_widget", "item_html", $html);		// HTML
 		$this->tmpl->addVar("_widget", "item_html2", $html2);		// HTML(続き)
 		switch ($status){
@@ -396,8 +412,10 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			case 2:	$this->tmpl->addVar("_widget", "selected_public", 'selected');	break;
 			case 3:	$this->tmpl->addVar("_widget", "selected_closed", 'selected');	break;
 		}
+			
 		$this->tmpl->addVar("_widget", "entry_user", $reg_user);	// 投稿者
-		$this->tmpl->addVar("_widget", "entry_dt", $reg_dt);	// 投稿日時
+		$this->tmpl->addVar("_widget", "entry_date", $entry_date);	// 投稿日
+		$this->tmpl->addVar("_widget", "entry_time", $entry_time);	// 投稿時
 		$this->tmpl->addVar("_widget", "update_user", $update_user);	// 更新者
 		$this->tmpl->addVar("_widget", "update_dt", $update_dt);	// 更新日時
 		
