@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_mainWidgetContainer.php 855 2008-07-24 01:39:20Z fishbone $
+ * @version    SVN: $Id: blog_mainWidgetContainer.php 1453 2009-01-19 08:40:44Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -22,7 +22,6 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
 	private $commentDb;			// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $currentDay;		// 現在日
 	private $currentHour;		// 現在時間
 	private $currentPageUrl;			// 現在のページURL
@@ -31,30 +30,27 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 	private $isExistsViewData;				// 表示データがあるかどうか
 	private $viewExtEntry;			// 続きを表示するかどうか
 	const CONTENT_TYPE = 'bg';
-	const DEFAULT_LIST_COUNT = 5;			// 最大リスト表示数
-	const DEFAULT_SEARCH_LIST_COUNT = 5;			// 最大リスト表示数
 	const RECEIVE_COMMENT		= 'receive_comment';		// コメントを受け付けるかどうか
 	const RECEIVE_TRACKBACK		= 'receive_trackback';		// トラックバックを受け付けるかどうか
 	const ENTRY_VIEW_COUNT		= 'entry_view_count';			// 記事表示数
 	const ENTRY_VIEW_ORDER		= 'entry_view_order';			// 記事表示方向
+	const LINK_PAGE_COUNT		= 5;			// リンクページ数
 	const MESSAGE_NO_ENTRY		= 'ブログ記事は登録されていません';				// ブログ記事が登録されていないメッセージ
 	const MESSAGE_EXT_ENTRY		= '続きを読む';					// 投稿記事に続きがある場合の表示
 	const MESSAGE_EXT_ENTRY_PRE	= '…&nbsp;';							// 投稿記事に続きがある場合の表示
+	const DEFAULT_VIEW_COUNT	= 10;				// デフォルトの表示記事数
 	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DBオブジェクト作成
 		$this->db = new blog_mainDb();
 		$this->commentDb = new blog_commentDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -86,23 +82,22 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gAccessManager;
-				
 		// 初期設定値
+		$now = date("Y/m/d H:i:s");	// 現在日時
 		$this->currentDay = date("Y/m/d");		// 日
 		$this->currentHour = (int)date("H");		// 時間
-		$this->currentPageUrl = $gEnvManager->createCurrentPageUrl();// 現在のページURL
-		$this->langId = $gEnvManager->getDefaultLanguage();
+		$this->currentPageUrl = $this->gEnv->createCurrentPageUrl();// 現在のページURL
+		$this->langId = $this->gEnv->getCurrentLanguage();
 		$sendButtonLabel = 'コメントを投稿';		// 送信ボタンラベル
 		$sendStatus = 0;		// 送信状況
-		$regUserId		= $gEnvManager->getCurrentUserId();			// 記事投稿ユーザ
+		$regUserId		= $this->gEnv->getCurrentUserId();			// 記事投稿ユーザ
 		$regDt			= date("Y/m/d H:i:s");						// 投稿日時
 		$this->isOutputComment = false;// コメントを出力するかどうか
 		$yearMonth = '';		// 表示年月日
 		
 		// 定義値取得
 		$entryViewCount	= $this->db->getConfig(self::ENTRY_VIEW_COUNT);// 記事表示数
+		if (empty($entryViewCount)) $entryViewCount = self::DEFAULT_VIEW_COUNT;
 		$entryViewOrder	= $this->db->getConfig(self::ENTRY_VIEW_ORDER);// 記事表示順
 		$receiveComment = $this->db->getConfig(self::RECEIVE_COMMENT);		// コメントを受け付けるかどうか
 		
@@ -121,17 +116,30 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		$email = $request->trimValueOf('email');
 		$url = $request->trimValueOf('url');
 		$body = $request->trimValueOf('body');
+		// ページ番号
+		$pageNo = $request->trimIntValueOf('page', '1');				// ページ番号
 		
 		$showDefault = false;			// デフォルト状態での表示
 		$this->viewExtEntry = false;			// 続きを表示するかどうか
 		if ($act == 'search'){			// 検索
-			$itemCount = self::DEFAULT_SEARCH_LIST_COUNT;		// 取得数
-			
 			// キーワード検索のとき
 			if (empty($keyword)){
 				$keyword = '検索キーワードが入力されていません';
 			} else {
-				$this->db->searchEntryItemsByKeyword($itemCount, 1, $keyword, $gEnvManager->getCurrentLanguage(), array($this, 'searchItemsLoop'));
+				// 総数を取得
+				$totalCount = $this->db->searchEntryItemsCountByKeyword($now, $keyword, $this->langId);
+
+				// リンク文字列作成、ページ番号調整
+				$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=search&keyword=' . urlencode($keyword));
+				
+				// 記事一覧を表示
+				$this->db->searchEntryItemsByKeyword($entryViewCount, $pageNo, $now, $keyword, $this->langId, array($this, 'searchItemsLoop'));
+				
+				if ($this->isExistsViewData){
+					// ページリンクを埋め込む
+					$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+					$this->tmpl->addVar("page_link", "page_link", $pageLink);
+				}
 			}
 		} else if ($act == 'view'){			// 記事を表示のとき
 			// コメントを受け付けるときは、コメント入力欄を表示
@@ -140,16 +148,42 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 				$this->tmpl->setAttribute('entry_footer', 'visibility', 'visible');		// コメントへのリンク
 			}
 			if (!empty($category)){				// カテゴリー指定のとき
-				$this->db->getEntryItemsByCategory($category, $entryViewCount, $gEnvManager->getCurrentLanguage(), $entryViewOrder, array($this, 'itemsLoop'));
+				// 総数を取得
+				$totalCount = $this->db->getEntryItemsCountByCategory($now, $category, $this->langId);
+
+				// リンク文字列作成、ページ番号調整
+				$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=view&category=' . $category);
+				
+				// 記事一覧を表示
+				$this->db->getEntryItemsByCategory($entryViewCount, $pageNo, $now, $category, $this->langId, $entryViewOrder, array($this, 'itemsLoop'));
 
 				// ブログ記事データがないときはデータなしメッセージ追加
-				if (!$this->isExistsViewData) $yearMonth .= '&nbsp;&nbsp;' . self::MESSAGE_NO_ENTRY;
+				if ($this->isExistsViewData){
+					// ページリンクを埋め込む
+					$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+					$this->tmpl->addVar("page_link", "page_link", $pageLink);
+				} else {
+					$yearMonth .= '&nbsp;&nbsp;' . self::MESSAGE_NO_ENTRY;
+				}
 			} else if (!empty($year) && !empty($month)){
 				if (empty($day)){		// 月指定のとき
 					$startDt = $year . '/' . $month . '/1';
 					$endDt = $this->getNextMonth($year . '/' . $month) . '/1';
-					$this->db->getEntryItems($entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $entryViewCount, $gEnvManager->getCurrentLanguage(), $entryViewOrder, array($this, 'itemsLoop'));
+					
+					// 総数を取得
+					$totalCount = $this->db->getEntryItemsCount($now, $startDt, $endDt, $this->langId);
 
+					// リンク文字列作成、ページ番号調整
+					$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=view&year=' . $year . '&month=' . $month);
+				
+					// 記事一覧作成
+					$this->db->getEntryItems($entryViewCount, $pageNo, $now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $entryViewOrder, array($this, 'itemsLoop'));
+
+					if ($this->isExistsViewData){
+						// ページリンクを埋め込む
+						$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+						$this->tmpl->addVar("page_link", "page_link", $pageLink);
+					}
 					// 年月の表示
 					$yearMonth = $year . '年 ' . $month . '月';
 					// ブログ記事データがないときはデータなしメッセージ追加
@@ -157,7 +191,21 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 				} else {
 					$startDt = $year . '/' . $month . '/' . $day;
 					$endDt = $this->getNextDay($year . '/' . $month . '/' . $day);
-					$this->db->getEntryItems($entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $entryViewCount, $gEnvManager->getCurrentLanguage(), $entryViewOrder, array($this, 'itemsLoop'));
+					
+					// 総数を取得
+					$totalCount = $this->db->getEntryItemsCount($now, $startDt, $endDt, $this->langId);
+
+					// リンク文字列作成、ページ番号調整
+					$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->currentPageUrl . '&act=view&year=' . $year . '&month=' . $month . '&day=' . $day);
+					
+					// 記事一覧作成
+					$this->db->getEntryItems($entryViewCount, $pageNo, $now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $entryViewOrder, array($this, 'itemsLoop'));
+					
+					if ($this->isExistsViewData){
+						// ページリンクを埋め込む
+						$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+						$this->tmpl->addVar("page_link", "page_link", $pageLink);
+					}
 					
 					// 年月日の表示
 					$yearMonth = $year . '年 ' . $month . '月 ' . $day . '日';
@@ -173,7 +221,7 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 			// エラーなしの場合は確認画面表示
 			if ($this->getMsgCount() == 0){
 				// ハッシュキー作成
-				$postTicket = md5(time() . $gAccessManager->getAccessLogSerialNo());
+				$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
 				$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
 				$this->tmpl->addVar("_widget", "ticket", $postTicket);				// 画面に書き出し
 				
@@ -199,12 +247,12 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 			}
 			
 			// 入力値を戻す
-			$this->tmpl->addVar("add_comment", "title", $title);
-			$this->tmpl->addVar("add_comment", "name", $name);
-			$this->tmpl->addVar("add_comment", "email", $email);
-			$this->tmpl->addVar("add_comment", "url", $url);
-			$this->tmpl->addVar("add_comment", "body", $body);
-			$this->tmpl->addVar("_widget", "entry_id", $entryId);		// 記事ID
+			$this->tmpl->addVar("add_comment", "title", $this->convertToDispString($title));
+			$this->tmpl->addVar("add_comment", "name", $this->convertToDispString($name));
+			$this->tmpl->addVar("add_comment", "email", $this->convertToDispString($email));
+			$this->tmpl->addVar("add_comment", "url", $this->convertToDispString($url));
+			$this->tmpl->addVar("add_comment", "body", $this->convertToDispString($body));
+			$this->tmpl->addVar("_widget", "entry_id", $this->convertToDispString($entryId));		// 記事ID
 		} else if ($act == 'sendcomment'){	// コメント受信のとき
 			$postTicket = $request->trimValueOf('ticket');		// POST確認用
 			$ret = false;
@@ -242,8 +290,25 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 					$this->tmpl->addVar("add_comment", "send_status", $sendStatus);// 送信状況
 				}
 			}
-			if (!empty($entryId)) $this->viewExtEntry = true;			// 続きを表示
-			$this->db->getEntryItems($entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $entryViewCount, $gEnvManager->getCurrentLanguage(), $entryViewOrder, array($this, 'itemsLoop'));
+			if (empty($entryId)){
+				// 総数を取得
+				$totalCount = $this->db->getEntryItemsCount($now, $startDt, $endDt, $this->langId);
+
+				// リンク文字列作成、ページ番号調整
+				$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->currentPageUrl);
+				
+				// 記事一覧作成
+				$this->db->getEntryItems($entryViewCount, $pageNo, $now, 0/* 期間で指定 */, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $entryViewOrder, array($this, 'itemsLoop'));
+				
+				if ($this->isExistsViewData){
+					// ページリンクを埋め込む
+					$this->tmpl->setAttribute('page_link', 'visibility', 'visible');		// リンク表示
+					$this->tmpl->addVar("page_link", "page_link", $pageLink);
+				}
+			} else {
+				$this->viewExtEntry = true;			// 記事ID指定のときは続き(全文)を表示
+				$this->db->getEntryItems($entryViewCount, $pageNo, $now, $entryId, $startDt/*期間開始*/, $endDt/*期間終了*/, $this->langId, $entryViewOrder, array($this, 'itemsLoop'));
+			}
 			
 			// 年月日の表示
 			// ブログ記事データがないときはデータなしメッセージ追加
@@ -262,12 +327,9 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 	 */
 	function itemsLoop($index, $fetchedRow)
 	{
-		global $gEnvManager;
-		global $gAnalyzeManager;
-			
 		// 参照ビューカウントを更新
-		if (!$gEnvManager->isSystemAdmin()){		// システム管理者の場合はカウントしない
-			$gAnalyzeManager->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['be_serial'], $this->currentDay, $this->currentHour);
+		if (!$this->gEnv->isSystemAdmin()){		// システム管理者の場合はカウントしない
+			$this->gAnalyze->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['be_serial'], $this->currentDay, $this->currentHour);
 		}
 
 		$entryId = $fetchedRow['be_id'];// 記事ID
@@ -282,13 +344,13 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 			if ($ret){
 				$this->tmpl->clearTemplate('commentlist');
 				for ($i = 0; $i < count($row); $i++){
-					$userName = $row[$i]['bo_user_name'];	// 投稿ユーザは入力値を使用
-					$url = $row[$i]['bo_url'];
-					$commentInfo = $row[$i]['bo_regist_dt'] . '&nbsp;&nbsp;' . $userName;
-					if (!empty($url)) $commentInfo .= '<br>' . $url;
-					$comment = $this->convertToPreviewText($row[$i]['bo_html']);		// 改行コードをbrタグに変換
+					$userName = $this->convertToDispString($row[$i]['bo_user_name']);	// 投稿ユーザは入力値を使用
+					$url = $this->convertToDispString($row[$i]['bo_url']);
+					$commentInfo = $this->convertToDispString($row[$i]['bo_regist_dt']) . '&nbsp;&nbsp;' . $userName;
+					if (!empty($url)) $commentInfo .= '<br />' . $url;
+					$comment = $this->convertToPreviewText($this->convertToDispString($row[$i]['bo_html']));		// 改行コードをbrタグに変換
 					$commentRow = array(
-						'comment_title'		=> $row[$i]['bo_name'],			// コメントタイトル
+						'comment_title'		=> $this->convertToDispString($row[$i]['bo_name']),			// コメントタイトル
 						'comment'		=> $comment,			// コメント内容
 						'user_name'		=> $userName,			// 投稿ユーザ名
 						'comment_info'	=> $commentInfo						// コメント情報
@@ -309,18 +371,18 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		
 		// 記事へのリンクを生成
 		$linkUrl = $this->currentPageUrl . '&entryid=' . $entryId;
-		$link = '<a href="' . $linkUrl . '" >コメント(' . $commentCount . ')</a>';
+		$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >コメント(' . $commentCount . ')</a>';
 		
 		// HTMLを出力(出力内容は特にエラーチェックしない)
 		$entryText = $fetchedRow['be_html'];
 		if ($this->viewExtEntry){			// 続きを表示するかどうか
 			if (!empty($fetchedRow['be_html_ext'])) $entryText = $fetchedRow['be_html_ext'];// 続きがある場合は続きを出力
-			$entryText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $entryText);// アプリケーションルートを変換
+			$entryText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $entryText);// アプリケーションルートを変換
 		} else {
 			// 続きがある場合はリンクを付加
-			$entryText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $entryText);// アプリケーションルートを変換
+			$entryText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $entryText);// アプリケーションルートを変換
 			if (!empty($fetchedRow['be_html_ext'])){
-				$entryText .= self::MESSAGE_EXT_ENTRY_PRE . '<a href="' . $linkUrl . '" >' . self::MESSAGE_EXT_ENTRY . '</a>';
+				$entryText .= self::MESSAGE_EXT_ENTRY_PRE . '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >' . self::MESSAGE_EXT_ENTRY . '</a>';
 			}
 		}
 
@@ -352,14 +414,12 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 	 */
 	function searchItemsLoop($index, $fetchedRow)
 	{
-		global $gEnvManager;
-
 		// タイトルを設定
 		$title = $fetchedRow['be_name'];
 		
 		// 記事へのリンクを生成
 		$linkUrl = $this->currentPageUrl . '&entryid=' . $fetchedRow['be_id'];
-		$link = '<a href="' . $linkUrl . '" >' . $title . '</a>';
+		$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >' . $title . '</a>';
 		
 		// 日付
 		$date = $fetchedRow['be_regist_dt'];
@@ -367,9 +427,9 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		// HTMLを出力(出力内容は特にエラーチェックしない)
 		// 続きがある場合はリンクを付加
 		$entryText = $fetchedRow['be_html'];
-		$entryText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $entryText);// アプリケーションルートを変換
+		$entryText = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $entryText);// アプリケーションルートを変換
 		if (!empty($fetchedRow['be_html_ext'])){
-			$entryText .= self::MESSAGE_EXT_ENTRY_PRE . '<a href="' . $linkUrl . '" >' . self::MESSAGE_EXT_ENTRY . '</a>';
+			$entryText .= self::MESSAGE_EXT_ENTRY_PRE . '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >' . self::MESSAGE_EXT_ENTRY . '</a>';
 		}
 
 		$row = array(
@@ -382,5 +442,51 @@ class blog_mainWidgetContainer extends BaseWidgetContainer
 		$this->isExistsViewData = true;				// 表示データがあるかどうか
 		return true;
 	}
+	/**
+	 * ページリンク作成
+	 *
+	 * @param int $pageNo			ページ番号(1～)。ページ番号が範囲外にある場合は自動的に調整
+	 * @param int $totalCount		総項目数
+	 * @param int $viewItemCount	1ページあたりの項目数
+	 * @param string $baseUrl		リンク用のベースURL
+	 * @return string				リンクHTML
+	 */
+	function createPageLink(&$pageNo, $totalCount, $viewItemCount, $baseUrl)
+	{
+		// 表示するページ番号の修正
+		$pageCount = (int)(($totalCount -1) / $viewItemCount) + 1;		// 総ページ数
+		if ($pageNo < 1) $pageNo = 1;
+		if ($pageNo > $pageCount) $pageNo = $pageCount;
+
+		// ページング用リンク作成
+		$pageLink = '';
+		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
+			//for ($i = 1; $i <= $pageCount; $i++){
+			// ページ数1から「LINK_PAGE_COUNT」までのリンクを作成
+			$maxPageCount = $pageCount < self::LINK_PAGE_COUNT ? $pageCount : self::LINK_PAGE_COUNT;
+			for ($i = 1; $i <= $maxPageCount; $i++){
+				if ($i == $pageNo){
+					$link = '&nbsp;' . $i;
+				} else {
+					$linkUrl = $baseUrl . '&page=' . $i;
+					$link = '&nbsp;<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >' . $i . '</a>';
+				}
+				$pageLink .= $link;
+			}
+			// 残りは「...」表示
+			if ($pageCount > self::LINK_PAGE_COUNT) $pageLink .= '&nbsp;...';
+		}
+		if ($pageNo > 1){		// 前ページがあるとき
+			$linkUrl = $baseUrl . '&page=' . ($pageNo -1);
+			$link = '<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >前へ</a>';
+			$pageLink = $link . $pageLink;
+		}
+		if ($pageNo < $pageCount){		// 次ページがあるとき
+			$linkUrl = $baseUrl . '&page=' . ($pageNo +1);
+			$link = '&nbsp;<a href="' . $this->convertUrlToHtmlEntity($linkUrl) . '" >次へ</a>';
+			$pageLink .= $link;
+		}
+		return $pageLink;
+	}
 }
 ?>
