@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: blog_new_boxWidgetContainer.php 2 2007-11-03 04:59:01Z fishbone $
+ * @version    SVN: $Id: blog_new_boxWidgetContainer.php 1439 2009-01-14 04:00:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -22,6 +22,7 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 	private $db;	// DB接続オブジェクト
 	private $sysDb;		// システムDBオブジェクト
 	private $isEntry;	// 記事の投稿があるかどうか
+	private $scriptUrl;
 	const TARGET_WIDGET = 'blog_main';		// 呼び出しウィジェットID
 	const THIS_WIDGET_ID = 'blog_new_box';		// ウィジェットID
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
@@ -66,10 +67,6 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		global $gDesignManager;
-
 		// DBの保存設定値を取得
 		$itemCount = self::DEFAULT_LIST_COUNT;				// 表示項目数
 		$serializedParam = $this->sysDb->getWidgetParam(self::THIS_WIDGET_ID);
@@ -78,13 +75,14 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 			$itemCount = $dispInfo->viewCount;		// 一覧表示数
 		}
 		// 新規ブログタイトルを取得
-		$this->db->getEntryItems($itemCount, $gEnvManager->getCurrentLanguage(), array($this, 'itemLoop'));
+		$this->scriptUrl = $this->gEnv->getCurrentScriptUrl();			// 現在実行されているスクリプトURL
+		$this->db->getEntryItems($itemCount, $this->gEnv->getCurrentLanguage(), array($this, 'itemLoop'));
 			
 		if (!$this->isEntry){	// 記事の投稿がないときはメッセージを出力
 			$this->tmpl->addVar("_widget", "message", '投稿記事はありません');
 		}
 		// メニューテーブルのパラメータ
-		$this->tmpl->addVar("_widget", "default_menu_param", $gDesignManager->getDefaultWidgetTableParam());
+		$this->tmpl->addVar("_widget", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -96,8 +94,6 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 	 */
 	function itemLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		// タイトルを設定
 		$title = $fetchedRow['be_name'];
 		// タイトルの長さは制限
@@ -108,11 +104,12 @@ class blog_new_boxWidgetContainer extends BaseWidgetContainer
 		}
 		
 		// 記事へのリンク
-		$url  = '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
+		$url  = $this->scriptUrl;
+		$url .= '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
 		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . self::TARGET_WIDGET;
 		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . self::THIS_WIDGET_ID;		// 送信元
 		$url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode('entryid=' . $fetchedRow['be_id']);
-		$nameLink = '<a href="' . $url . '">' . $title . '</a>';
+		$nameLink = '<a href="' . $this->convertUrlToHtmlEntity($url) . '">' . $title . '</a>';
 
 		$row = array(
 			'new_item' => $nameLink
