@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blogparts_boxWidgetContainer.php 1424 2009-01-07 04:29:09Z fishbone $
+ * @version    SVN: $Id: admin_blogparts_boxWidgetContainer.php 1615 2009-03-23 04:09:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -26,7 +26,7 @@ class admin_blogparts_boxWidgetContainer extends BaseWidgetContainer
 	private $paramObj;		// パラメータ保存用オブジェクト
 	const CONTENT_TYPE = 'blogparts';			// コンテンツタイプ
 	const DEFAULT_NAME_HEAD = '名称未設定';			// デフォルトの設定名
-	const DEFAULT_CONTENT = '<object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://fpdownload.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0" width="168" height="300" id="500musicbooth002" align="middle"><param name="allowScriptAccess" value="always" /><param name="movie" value="http://www.fiat-auto.co.jp/blogparts/500musicbooth/500musicbooth002.swf" /><param name="quality" value="high" /><param name="wmode" value="transparent"><param name="bgcolor" value="#ffffff" /><embed src="http://www.fiat-auto.co.jp/blogparts/500musicbooth/500musicbooth002.swf" quality="high" bgcolor="#ffffff" width="168" height="300" name="500musicbooth002" align="middle" wmode="transparent" allowScriptAccess="always" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" /></object>';
+	const DEFAULT_CONTENT = '<div style="width:151px;margin-bottom:10px;margin-left:3px;"><iframe allowtransparency="true" width="151" height="500" frameborder="0" scrolling="no" marginheight="0" marginwidth="0" src="http://www.playtable.jp/album_exp.php?BrowseNodeId=564624&ItemId=B000002J01"></iframe></div>';
 	
 	/**
 	 * コンストラクタ
