@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 1250 2008-11-18 09:23:12Z fishbone $
+ * @version    SVN: $Id: index.php 1471 2009-01-25 11:40:16Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -38,8 +38,8 @@ $HELP['content_update_user']['title'] = '更新者';
 $HELP['content_update_user']['body'] = 'コンテンツを更新したユーザです。';
 $HELP['content_update_dt']['title'] = '更新日時';
 $HELP['content_update_dt']['body'] = 'コンテンツを更新した日時です。';
-$HELP['content_view_count']['title'] = '参照数';
-$HELP['content_view_count']['body'] = 'コンテンツがユーザに参照された回数です。管理者の参照はカウントされません。';
+$HELP['content_view_count']['title'] = '閲覧数';
+$HELP['content_view_count']['body'] = 'コンテンツがユーザに閲覧された回数です。管理者の閲覧はカウントされません。';
 $HELP['content_act']['title'] = '操作';
 $HELP['content_act']['body'] = '各種操作を行います。<br />●メニューに追加<br />「メインメニュー」ウィジェットにコンテンツを表示するメニュー項目を追加します。';
 $HELP['content_html']['title'] = 'HTML';
