@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuWidgetContainer.php 1370 2008-12-19 04:28:06Z fishbone $
+ * @version    SVN: $Id: default_menuWidgetContainer.php 1387 2008-12-24 08:53:57Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -67,30 +67,24 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		if (empty($configId)) $configId = self::DEFAULT_CONFIG_ID;
 		
 		// パラメータオブジェクトを取得
-		$this->paramObj = $this->getWidgetParamObjectWithId();
-
-		// 指定定義IDのデータを取得
-		$name = '';
-		for ($i = 0; $i < count($this->paramObj); $i++){
-			$id			= $this->paramObj[$i]->id;// 定義ID
-			$targetObj	= $this->paramObj[$i]->object;
-			if ($id == $configId){
-				$menuId		= $targetObj->menuId;	// メニューID
-				$name		= $targetObj->name;// 定義名
-				$showTitle	= $targetObj->showTitle;// タイトルを表示するかどうか
-				break;
-			}
-		}
-		if ($i < count($this->paramObj)){		// 該当する定義IDのデータが取得できたとき
+		$targetObj = $this->getWidgetParamObjByConfigId($configId);
+		if (!empty($targetObj)){		// 定義データが取得できたとき
+			$menuId		= $targetObj->menuId;	// メニューID
+			$name		= $targetObj->name;// 定義名
+			$showTitle	= $targetObj->showTitle;// タイトルを表示するかどうか
+			$limitUser	= $targetObj->limitUser;// ユーザを制限するかどうか
 			
-			$this->tmpl->setAttribute('show_html', 'visibility', 'visible');
+			// ユーザ制限があるときはログイン時のみ表示
+			if (!$limitUser || $this->gEnv->isCurrentUserLogined()){
+				$this->tmpl->setAttribute('show_html', 'visibility', 'visible');
 						
-			// 表示データ埋め込み
-			$this->tmpl->addVar("show_html", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
-			if ($showTitle) $this->tmpl->addVar("show_html", "title", '<tr><th>' . $name . '</th><tr>');
+				// 表示データ埋め込み
+				$this->tmpl->addVar("show_html", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
+				if ($showTitle) $this->tmpl->addVar("show_html", "title", '<tr><th>' . $name . '</th></tr>');
 			
-			// メニュー作成
-			$this->createMenu($menuId, 0);
+				// メニュー作成
+				$this->createMenu($menuId, 0);
+			}
 		}
 	}
 	/**
@@ -150,23 +144,6 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 		
 				$index++;		// インデックス番号更新
 				$this->isExistsMenuItem = true;		// メニュー項目が存在するかどうか
-				
-				// ##### ツリーメニュー作成 #####
-				/*
-				if ($row['md_type'] == 0){	// リンク項目のとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . $this->convertToDispString($row['md_name']) . '</span></li>' . M3_NL;
-				} else if ($row['md_type'] == 1){			// フォルダのとき
-					// サブメニュー作成
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . $this->convertToDispString($row['md_name']) . '</span>' . M3_NL;
-					$treeHtml .= '<ul>' . M3_NL;
-					$treeHtml .= $this->createMenu($menuId, $row['md_id'], $level + 1);
-					$treeHtml .= '</ul>' . M3_NL;
-					$treeHtml .= '</li>' . M3_NL;
-				} else if ($row['md_type'] == 2){			// テキストのとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . $this->convertToDispString($row['md_name']) . '</span></li>' . M3_NL;
-				} else if ($row['md_type'] == 3){			// セパレータのとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><span>' . '-----' . '</span></li>' . M3_NL;
-				}*/
 			}
 		}
 		return $treeHtml;
