@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuDb.php 1370 2008-12-19 04:28:06Z fishbone $
+ * @version    SVN: $Id: default_menuDb.php 1379 2008-12-22 10:31:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -46,5 +46,18 @@ class default_menuDb extends BaseDb
 		$retValue = $this->selectRecords($queryStr, array($menuId, $parentId), $rows);
 		return $retValue;
 	}
+	/**
+	 * メニュー情報の取得
+	 *
+	 * @param string  $id			メニューID
+	 * @return						true=正常、false=異常
+	 */
+	function getMenu($id, &$row)
+	{
+		$queryStr  = 'SELECT * FROM _menu_id ';
+		$queryStr .=   'WHERE mn_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($id), $row);
+		return $ret;
+	}
 }
 ?>
