@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainDelivmethodWidgetContainer.php 227 2008-04-23 04:52:18Z naoki $
+ * @version    SVN: $Id: admin_ec_mainDelivmethodWidgetContainer.php 1682 2009-04-01 04:38:03Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -26,20 +26,19 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	const IWIDGET_TYPE = 'DELIVERY';		// 配送方法用インナーウィジェット
 	const TARGET_WIDGET = 'ec_main';		// プレビュー画面表示用
+	const DELIV_TASK = 'delivmethod';		// 配送方法選択画面表示用
 	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
 		// DBオブジェクト作成
 		$this->db = new ec_mainDelivMethodDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -86,10 +85,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	 */
 	function createList($request)
 	{
-		global $gEnvManager;
-		global $gPageManager;
-		
-		$this->langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
+		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
 		$act = $request->trimValueOf('act');
 		
 		if ($act == 'delete'){		// 項目削除の場合
@@ -119,7 +115,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		
 		// プレビュー表示ボタンのリンクを作成
-		$url = $gPageManager->createWidgetCmdUrl($gEnvManager->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, 'task=delivery');
+		$url = $this->gPage->createWidgetCmdUrl($this->gEnv->getDefaultPageId(), self::TARGET_WIDGET, ''/*送信元ウィジェット指定なし*/, 'task=' . self::DELIV_TASK);
 		$this->tmpl->addVar("_widget", "url", $url);
 	}
 	/**
@@ -130,9 +126,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	 */
 	function createDetail($request)
 	{
-		global $gEnvManager;
-		
-		$this->langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
+		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
 		$act = $request->trimValueOf('act');
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
 		if (empty($this->serialNo)) $this->serialNo = 0;
@@ -161,6 +155,9 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 				if (!empty($this->iWidgetId)){
 					// インナーウィジェットでのパラメータの更新に成功した場合
 					$this->updateIWidgetParam($this->iWidgetId, $this->id, $param, $optionParam, true);
+					
+					// インナーウィジェット内で発生したエラーを取得
+					$this->getGlobalMsg();
 				}
 			}
 			
@@ -186,6 +183,9 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 				if (!empty($this->iWidgetId)){
 					// インナーウィジェットでのパラメータの更新に成功した場合
 					$this->updateIWidgetParam($this->iWidgetId, $this->id, $param, $optionParam, true);
+					
+					// インナーウィジェット内で発生したエラーを取得
+					$this->getGlobalMsg();
 				}
 			}
 			
@@ -207,6 +207,11 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 				$this->setMsg(self::MSG_APP_ERR, '項目削除に失敗しました');
 			}
 		} else if ($act == 'selectcalc'){		// 計算方法選択のとき
+			if (!empty($this->iWidgetId)){
+				// パラメータをインナーウィジェットに設定
+				$optionParam->init = true;		// 初期データ取得
+				$this->setIWidgetParam($this->iWidgetId, $this->id, $row['do_param'], $optionParam, true);
+			}
 		} else {		// 初期状態
 			// シリアル番号からIDを取得
 			$this->id = $this->db->getDelivMethodDefIdBySerial($this->serialNo);			// 選択中の配送項目ID
@@ -235,6 +240,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 				$this->iWidgetId	= $row['do_iwidget_id'];	// インナーウィジェットID
 				if (!empty($this->iWidgetId)){
 					// パラメータをインナーウィジェットに設定
+					$optionParam->init = true;		// 初期データ取得
 					$this->setIWidgetParam($this->iWidgetId, $this->id, $row['do_param'], $optionParam, true);
 				}
 			}
@@ -263,7 +269,7 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		$this->tmpl->addVar("_widget", "visible", $visibleStr);		// 表示状態
 		
 		// インナーウィジェット選択メニューを作成
-		$this->sysDb->getAllIWidgetListByType($gEnvManager->getCurrentWidgetId(), self::IWIDGET_TYPE, array($this, 'iWidgetLoop'));
+		$this->sysDb->getAllIWidgetListByType($this->gEnv->getCurrentWidgetId(), self::IWIDGET_TYPE, array($this, 'iWidgetLoop'));
 		
 		// 選択中のインナーウィジェットの管理画面を取得
 		if (!empty($this->iWidgetId)){
@@ -272,8 +278,8 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 		}
 
 		// パスの設定
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		$this->tmpl->addVar("_widget", "widget_sc_url", $gEnvManager->getCurrentWidgetScriptsUrl());
+		$this->tmpl->addVar("_widget", "root_url", $this->gEnv->getRootUrl());
+		$this->tmpl->addVar("_widget", "widget_sc_url", $this->gEnv->getCurrentWidgetScriptsUrl());
 	}
 	/**
 	 * 取得した配送方法定義をテンプレートに設定する
@@ -285,13 +291,6 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	 */
 	function delivDefLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
 		$checked = '';
 		if ($fetchedRow['do_id'] == $this->id){
 			$checked = 'checked';
@@ -301,7 +300,6 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 			$visible = 'checked';
 		}
 		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
 			'serial' => $fetchedRow['do_serial'],								// シリアル番号
 			'index' => $index,													// 項目番号
 			'id'     => $this->convertToDispString($fetchedRow['do_id']),			// ID
@@ -327,8 +325,6 @@ class admin_ec_mainDelivmethodWidgetContainer extends admin_ec_mainBaseWidgetCon
 	 */
 	function iWidgetLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$id = $fetchedRow['iw_widget_id'] . ',' . $fetchedRow['iw_id'];
 		$selected = '';
 		if ($id == $this->iWidgetId){		// 選択中のインナーウィジェット
