@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainOrderWidgetContainer.php 593 2008-05-08 03:24:11Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainOrderWidgetContainer.php 1583 2009-03-16 04:16:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -43,8 +43,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -53,7 +51,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->productDb = new productDb();
 		
 		// 価格計算用オブジェクト取得
-		$this->ecObj = $gInstanceManager->getObject(self::PRICE_OBJ_ID);
+		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -100,11 +98,9 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function createList($request)
 	{
-		global $gEnvManager;
-
 		// ユーザ情報、表示言語
-		$this->langId = $gEnvManager->getDefaultLanguage();		// デフォルト言語
-		$this->userId = $gEnvManager->getCurrentUserId();
+		$this->langId = $this->gEnv->getDefaultLanguage();		// デフォルト言語
+		$this->userId = $this->gEnv->getCurrentUserId();
 		
 		// ##### 検索条件 #####
 		$pageNo = $request->trimValueOf('page');				// ページ番号
@@ -167,8 +163,8 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$pageLink = '';
 		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
 			for ($i = 1; $i <= $pageCount; $i++){
-				$linkUrl = $gEnvManager->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
-				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId() . '&task=order&status=' . $this->search_status . '&page=' . $i;
+				$linkUrl = $this->gEnv->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET . 
+				'&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId() . '&task=order&status=' . $this->search_status . '&page=' . $i;
 				if ($i == $pageNo){
 					$link = '&nbsp;' . $i;
 				} else {
@@ -194,8 +190,8 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		
 		// 埋め込みパラメータの設定
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示中の項目のシリアル番号設定
-		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());
-		$this->tmpl->addVar('_widget', 'widget_id', $gEnvManager->getCurrentWidgetId());
+		$this->tmpl->addVar("_widget", "admin_url", $this->gEnv->getDefaultAdminUrl());
+		$this->tmpl->addVar('_widget', 'widget_id', $this->gEnv->getCurrentWidgetId());
 	}
 	/**
 	 * 詳細画面作成
@@ -205,12 +201,10 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function createDetail($request)
 	{
-		global $gEnvManager;
-
 		// ユーザ情報、表示言語
 		$this->now = date("Y/m/d H:i:s");	// 現在日時
-		$this->langId = $gEnvManager->getDefaultLanguage();		// デフォルト言語
-		$this->userId = $gEnvManager->getCurrentUserId();
+		$this->langId = $this->gEnv->getDefaultLanguage();		// デフォルト言語
+		$this->userId = $this->gEnv->getCurrentUserId();
 		
 		$act = $request->trimValueOf('act');
 		$this->serialNo = $request->trimValueOf('serial');			// 選択項目のシリアル番号
@@ -223,6 +217,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$custm_address2 = $request->trimValueOf('item_custm_address2');		// 顧客住所2
 		$custm_phone = $request->trimValueOf('item_custm_phone');		// 顧客電話番号
 		$custm_fax = $request->trimValueOf('item_custm_fax');		// 顧客FAX
+		$custm_email = $request->trimValueOf('item_custm_email');		// 顧客Eメール
 		
 		$deliv_name = $request->trimValueOf('item_deliv_name');		// 配送先名
 		$deliv_name_kana = $request->trimValueOf('item_deliv_name_kana');		// 配送先名(カナ)
@@ -231,6 +226,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$deliv_address2 = $request->trimValueOf('item_deliv_address2');		// 配送先住所2
 		$deliv_phone = $request->trimValueOf('item_deliv_phone');		// 配送先電話番号
 		$deliv_fax = $request->trimValueOf('item_deliv_fax');		// 配送先FAX
+		$deliv_email = $request->trimValueOf('item_deliv_email');		// 配送先Eメール
 		$bill_name = $request->trimValueOf('item_bill_name');		// 請求先名
 		$bill_name_kana = $request->trimValueOf('item_bill_name_kana');		// 請求先名(カナ)
 		$bill_zipcode = $request->trimValueOf('item_bill_zipcode');		// 請求先郵便番号
@@ -238,6 +234,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$bill_address2 = $request->trimValueOf('item_bill_address2');		// 請求先住所2
 		$bill_phone = $request->trimValueOf('item_bill_phone');		// 請求先電話番号
 		$bill_fax = $request->trimValueOf('item_bill_fax');		// 請求先FAX
+		$bill_email = $request->trimValueOf('item_bill_email');		// 請求先Eメール
 		$this->deliveryMethod = $request->trimValueOf('item_delivery_method');		// 選択中の配送方法
 		$this->payMethod = $request->trimValueOf('item_payment_method');			// 選択中の支払い方法
 		$this->custmState = $request->trimValueOf('item_custm_state');		// 顧客都道府県
@@ -256,6 +253,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			$this->checkInput($custm_address,		'顧客住所');	
 			$this->checkSingleByte($custm_phone,	'顧客電話番号');
 			$this->checkSingleByte($custm_fax,		'顧客FAX', true);
+			$this->checkMailAddress($custm_email,	'顧客Eメール');
 			
 			$this->checkInput($deliv_name,			'配送先名', true);		
 			$this->checkInput($deliv_name_kana,		'配送先名(カナ)', true);
@@ -264,6 +262,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			$this->checkInput($deliv_address,		'配送先住所', true);	
 			$this->checkSingleByte($deliv_phone,	'配送先電話番号', true);
 			$this->checkSingleByte($deliv_fax,		'配送先FAX', true);
+			$this->checkMailAddress($deliv_email,	'配送先Eメール', true);
 			
 			$this->checkInput($bill_name,			'請求先名', true);		
 			$this->checkInput($bill_name_kana,		'請求先名(カナ)', true);
@@ -272,6 +271,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			$this->checkInput($bill_address,		'請求先住所', true);	
 			$this->checkSingleByte($bill_phone,		'請求先電話番号', true);
 			$this->checkSingleByte($bill_fax,		'請求先FAX', true);
+			$this->checkMailAddress($bill_email,	'請求先Eメール', true);
 						
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
@@ -284,11 +284,11 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 					// 受注ヘッダ作成
 					$ret = $this->db->updateOrder($this->serialNo, $this->userId, $this->langId, $row['or_order_no'],
 						$row['or_custm_id'], $name, $nameKana, $row['or_custm_person'], $row['or_custm_person_kana'],
-						$custm_zipcode, $this->custmState, $custm_address, $custm_address2, $custm_phone, $custm_fax, $row['or_custm_country_id'], 
+						$custm_zipcode, $this->custmState, $custm_address, $custm_address2, $custm_phone, $custm_fax, $custm_email, $row['or_custm_country_id'], 
 						$row['or_deliv_id'], $deliv_name, $deliv_name_kana, $row['or_deliv_person'], $row['or_deliv_person_kana'],
-						$deliv_zipcode, $this->delivState, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $row['or_deliv_country_id'],
+						$deliv_zipcode, $this->delivState, $deliv_address, $deliv_address2, $deliv_phone, $deliv_fax, $deliv_email, $row['or_deliv_country_id'],
 						$row['or_bill_id'], $bill_name, $bill_name_kana, $row['or_bill_person'], $row['or_bill_person_kana'], 
-						$bill_zipcode, $this->billState, $bill_address, $bill_address2, $bill_phone, $bill_fax, $row['or_bill_country_id'],
+						$bill_zipcode, $this->billState, $bill_address, $bill_address2, $bill_phone, $bill_fax, $bill_email, $row['or_bill_country_id'],
 						$this->deliveryMethod, $this->payMethod, $row['or_card_type'], $row['or_card_owner'], $row['or_card_number'], $row['or_card_expires'],
 						$row['or_demand_dt'], $row['or_demand_time'], $row['or_appoint_dt'], $row['or_currency_id'], $row['or_subtotal'], $row['or_discount'], $row['or_deliv_fee'], $row['or_charge'], $row['or_total'],
 						$this->orderStatus, $row['or_estimate_dt'], $row['or_regist_dt'], $row['or_order_dt'], $row['or_deliv_dt'], $row['or_close_dt'],
@@ -328,6 +328,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$custm_address2 = '';		// 顧客住所2
 				$custm_phone = '';		// 顧客電話番号
 				$custm_fax = '';		// 顧客FAX
+				$custm_email = '';		// 顧客Eメール
 				$deliv_name = '';		// 配送先名
 				$deliv_name_kana = '';		// 配送先名(カナ)
 				$deliv_zipcode = '';		// 配送先郵便番号
@@ -335,6 +336,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$deliv_address2 = '';		// 配送先住所2
 				$deliv_phone = '';		// 配送先電話番号
 				$deliv_fax = '';		// 配送先FAX
+				$deliv_email = '';		// 配送先Eメール
 				$bill_name = '';		// 請求先名
 				$bill_name_kana = '';		// 請求先名(カナ)
 				$bill_zipcode = '';		// 請求先郵便番号
@@ -342,6 +344,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$bill_address2 = '';		// 請求先住所2
 				$bill_phone = '';		// 請求先電話番号
 				$bill_fax = '';		// 請求先FAX
+				$bill_email = '';		// 請求先Eメール
 				$this->deliveryMethod = '';		// 選択中の配送方法
 				$this->payMethod = '';			// 選択中の支払い方法
 				$this->custmState = 0;		// 顧客都道府県
@@ -360,10 +363,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$this->langId = $row['or_language_id'];		// 受注時の言語
 				$orderNo = $row['or_order_no'];		// 受注番号
 				
-				// ログインユーザ情報を取得
-				$ret = $this->db->getLoginUserById($row['or_user_id'], $loginUserRow);
-				if ($ret) $email = $loginUserRow['lu_account'];
-				
 				$name = $row['or_custm_name'];		// 顧客名
 				$nameKana = $row['or_custm_name_kana'];		// 顧客名(カナ)
 				$custm_zipcode = $row['or_custm_zipcode'];		// 顧客郵便番号
@@ -371,6 +370,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$custm_address2 = $row['or_custm_address2'];		// 顧客住所2
 				$custm_phone = $row['or_custm_phone'];		// 顧客電話番号
 				$custm_fax = $row['or_custm_fax'];		// 顧客FAX
+				$custm_email = $row['or_custm_email'];		// 顧客Eメール
 				
 				$deliv_name = $row['or_deliv_name'];		// 配送先名
 				$deliv_name_kana = $row['or_deliv_name_kana'];		// 配送先名(カナ)
@@ -379,6 +379,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$deliv_address2 = $row['or_deliv_address2'];		// 配送先住所2
 				$deliv_phone = $row['or_deliv_phone'];		// 配送先電話番号
 				$deliv_fax = $row['or_deliv_fax'];		// 配送先FAX
+				$deliv_email = $row['or_deliv_email'];		// 配送先Eメール
 				$bill_name = $row['or_bill_name'];		// 請求先名
 				$bill_name_kana = $row['or_bill_name_kana'];		// 請求先名(カナ)
 				$bill_zipcode = $row['or_bill_zipcode'];		// 請求先郵便番号
@@ -386,6 +387,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$bill_address2 = $row['or_bill_address2'];		// 請求先住所2
 				$bill_phone = $row['or_bill_phone'];		// 請求先電話番号
 				$bill_fax = $row['or_bill_fax'];		// 請求先FAX
+				$bill_email = $row['or_bill_email'];		// 請求先Eメール
 				$this->deliveryMethod = $row['or_deliv_method_id'];		// 選択中の配送方法
 				$this->payMethod = $row['or_pay_method_id'];			// 選択中の支払い方法
 				$this->custmState = $row['or_custm_state_id'];		// 顧客都道府県
@@ -399,6 +401,12 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 				$charge = $row['or_charge'];		// 手数料
 				$total = $row['or_total'];		// 総額
 				
+				$demand_dt = $row['or_demand_dt'];	// 希望日
+				$demand_time = $row['or_demand_time'];	// 希望時間帯
+				if ($demand_dt != $this->gEnv->getInitValueOfDate() || !empty($demand_time)){
+					$delivNote = '配達希望日：' . $this->convertToDispDate($demand_dt) . '&nbsp;' . $this->convertToDispString($demand_time);
+				}
+					
 				$updateUser = $this->convertToDispString($row['lu_name']);	// 更新者
 				$updateDt = $this->convertToDispDateTime($row['or_create_dt']);	// 更新日時
 				
@@ -418,12 +426,14 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 
 		$this->tmpl->addVar("_widget", "name", $name);		// 顧客名
 		$this->tmpl->addVar("_widget", "name_kana", $nameKana);		// 顧客名(カナ)
-		$this->tmpl->addVar("_widget", "email", $email);		// Eメールアドレス
+		$this->tmpl->addVar("_widget", "custm_email", $custm_email);		// Eメールアドレス
 		$this->tmpl->addVar("_widget", "custm_zipcode", $custm_zipcode);		// 顧客郵便番号
 		$this->tmpl->addVar("_widget", "custm_address", $custm_address);		// 顧客住所
 		$this->tmpl->addVar("_widget", "custm_address2", $custm_address2);		// 顧客住所2
 		$this->tmpl->addVar("_widget", "custm_phone", $custm_phone);		// 顧客電話番号
 		$this->tmpl->addVar("_widget", "custm_fax", $custm_fax);		// 顧客FAX
+		$this->tmpl->addVar("_widget", "custm_email", $custm_email);		// 顧客Eメール
+		$this->tmpl->addVar("_widget", "deliv_note", $delivNote);		// 配送希望日
 		
 		$this->tmpl->addVar("_widget", "deliv_name", $deliv_name);		// 配送先名		
 		$this->tmpl->addVar("_widget", "deliv_name_kana", $deliv_name_kana);		// 配送先名(カナ)	
@@ -432,6 +442,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "deliv_address2", $deliv_address2);		// 配送先住所2
 		$this->tmpl->addVar("_widget", "deliv_phone", $deliv_phone);		// 配送先電話番号
 		$this->tmpl->addVar("_widget", "deliv_fax", $deliv_fax);		// 配送先FAX
+		$this->tmpl->addVar("_widget", "deliv_email", $deliv_email);		// 配送先Eメール
 		$this->tmpl->addVar("_widget", "bill_name", $bill_name);		// 請求先名		
 		$this->tmpl->addVar("_widget", "bill_name_kana", $bill_name_kana);		// 請求先名(カナ)
 		$this->tmpl->addVar("_widget", "bill_zipcode", $bill_zipcode);		// 請求先郵便番号
@@ -439,6 +450,7 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "bill_address2", $bill_address2);		// 請求先住所2
 		$this->tmpl->addVar("_widget", "bill_phone", $bill_phone);		// 請求先電話番号
 		$this->tmpl->addVar("_widget", "bill_fax", $bill_fax);		// 請求先FAX
+		$this->tmpl->addVar("_widget", "bill_email", $bill_email);		// 請求先Eメール
 		
 		$subtotalStr = $this->ecObj->convertByCurrencyFormat($this->currency, $this->langId, $subtotal);
 		$this->tmpl->addVar("_widget", "subtotal", $subtotalStr);		// 商品総額
@@ -483,8 +495,8 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		}
 		// 埋め込みパラメータの設定
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);
-		$this->tmpl->addVar("_widget", "admin_url", $gEnvManager->getDefaultAdminUrl());
-		$this->tmpl->addVar('_widget', 'widget_id', $gEnvManager->getCurrentWidgetId());
+		$this->tmpl->addVar("_widget", "admin_url", $this->gEnv->getDefaultAdminUrl());
+		$this->tmpl->addVar('_widget', 'widget_id', $this->gEnv->getCurrentWidgetId());
 	}
 	/**
 	 * 取得したデータをテンプレートに設定する
@@ -496,13 +508,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function orderListLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
-		// 行カラーの設定
-		$lineColor = '';
-		if ($index % 2 != 0){
-			$lineColor = 'class="even"';		// 偶数行
-		}
 		// 項目選択のラジオボタンの状態
 		$selected = '';
 		if ($fetchedRow['or_serial'] == $this->serialNo){
@@ -526,26 +531,29 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 			
 		// 配送日時
 		$delibDt = '';
-		if ($fetchedRow['or_deliv_dt'] != $gEnvManager->getInitValueOfTimestamp()) $delibDt = $this->convertToDispDateTime($fetchedRow['or_deliv_dt']);
+		if ($fetchedRow['or_deliv_dt'] != $this->gEnv->getInitValueOfTimestamp()) $delibDt = $this->convertToDispDateTime($fetchedRow['or_deliv_dt']);
 		
 		// 会員ID
 		$memberId = intval($fetchedRow['or_custm_id']);
 		if ($memberId < 0) $memberId = $memberId * (-1);
+		
+		// 会員情報へのリンク
+		$nameLink = $this->convertToDispString($fetchedRow['or_custm_name']);
+		if (!empty($memberId)){
+			$nameLink = '<a href="#" onclick="selMember(' . $memberId . ');">' . $nameLink . '</a>';
+		}
 		$row = array(
-			'line_color' => $lineColor,											// 行のカラー
 			'index' => $index,													// 行番号
 			'serial' => $this->convertToDispString($fetchedRow['or_serial']),	// シリアル番号
 			'id' => $memberId,			// 会員ID
 			'order_no' => $this->convertToDispString($fetchedRow['or_order_no']),		// 受注番号
-			'name' => $this->convertToDispString($fetchedRow['or_custm_name']),		// 顧客名
+			'name' => $nameLink,		// 顧客名
 			'total' => $dispPrice,		// 購入額
 			'status' => $status,		// 受注ステータス
 			'lang' => $lang,													// 対応言語
 			'regist_dt' => $this->convertToDispDateTime($fetchedRow['or_regist_dt']),	// 受付日時
 			'deliv_dt' => $delibDt,	// 配送日時
-			//'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
 			'update_dt' => $this->convertToDispDateTime($fetchedRow['or_create_dt']),	// 更新日時
-			'default' => $default,											// デフォルト項目
 			'selected' => $selected												// 項目選択用ラジオボタン
 		);
 		$this->tmpl->addVars('itemlist', $row);
@@ -565,8 +573,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function orderItemLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		// 行カラーの設定
 		$lineColor = '';
 		if ($index % 2 != 0){
@@ -623,8 +629,8 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 		
 		// 商品詳細へのリンク
 		$url  = '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_FIND_WIDGET;
-		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $gEnvManager->getCurrentWidgetId();
-		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $gEnvManager->getCurrentWidgetId();		// 送信元
+		$url .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
+		$url .= '&' . M3_REQUEST_PARAM_FROM . '=' . $this->gEnv->getCurrentWidgetId();		// 送信元
 		$url .= '&' . M3_REQUEST_PARAM_OPERATION_TODO . '=' . urlencode('product=' . $fetchedRow['si_product_id']);
 			
 		$nameLink = '<a href="' . $url . '">' . $name . '</a>';
@@ -671,8 +677,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function customStateLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['gz_id'] == $this->custmState){		// 選択中の都道府県
 			$selected = 'selected';
@@ -697,8 +701,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function delivStateLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['gz_id'] == $this->delivState){		// 選択中の都道府県
 			$selected = 'selected';
@@ -723,8 +725,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function billStateLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['gz_id'] == $this->billState){		// 選択中の都道府県
 			$selected = 'selected';
@@ -750,8 +750,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 /*
 	function deliveryMethodLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['dm_id'] == $this->deliveryMethod){		// 選択中の配送方法
 			$selected = 'selected';
@@ -776,8 +774,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function delivMethodLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		//$checked = '';
 		$selected = '';
 		if ($fetchedRow['do_id'] == $this->deliveryMethod){		// 選択中の配送方法
@@ -816,8 +812,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function paymentMethodLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['po_id'] == $this->payMethod){		// 選択中の支払い方法
 			$selected = 'selected';
@@ -842,8 +836,6 @@ class admin_ec_mainOrderWidgetContainer extends admin_ec_mainBaseWidgetContainer
 	 */
 	function orderStatusLoop($index, $fetchedRow, $param)
 	{
-		global $gEnvManager;
-
 		$selected = '';
 		if ($fetchedRow['os_id'] == $this->orderStatus){		// 受注ステータス
 			$selected = 'selected';
