@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_mainPaymethodWidgetContainer.php 588 2008-05-07 03:42:08Z fishbone $
+ * @version    SVN: $Id: admin_ec_mainPaymethodWidgetContainer.php 1662 2009-03-28 11:30:00Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_ec_mainBaseWidgetContainer.php');
@@ -161,6 +161,9 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 				if (!empty($this->iWidgetId)){
 					// インナーウィジェットでのパラメータの更新に成功した場合
 					$this->updateIWidgetParam($this->iWidgetId, $this->id, $param, $optionParam, true);
+					
+					// インナーウィジェット内で発生したエラーを取得
+					$this->getGlobalMsg();
 				}
 			}
 			
@@ -186,6 +189,9 @@ class admin_ec_mainPaymethodWidgetContainer extends admin_ec_mainBaseWidgetConta
 				if (!empty($this->iWidgetId)){
 					// インナーウィジェットでのパラメータの更新に成功した場合
 					$this->updateIWidgetParam($this->iWidgetId, $this->id, $param, $optionParam, true);
+					
+					// インナーウィジェット内で発生したエラーを取得
+					$this->getGlobalMsg();
 				}
 			}
 			
