@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainLoginWidgetContainer.php 190 2008-02-13 09:37:52Z naoki $
+ * @version    SVN: $Id: ec_mainLoginWidgetContainer.php 1583 2009-03-16 04:16:39Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -27,14 +27,13 @@ class ec_mainLoginWidgetContainer extends BaseWidgetContainer
 	private $ecMailObj;	// メール連携オブジェクト
 	const MAIL_OBJ_ID = 'ecmail';
 	const EC_LIB_ID = "eclib";		// EC共通ライブラリオブジェクトID
-		
+	const CF_PERMIT_NON_MEMBER_ORDER = 'permit_non_member_order';			// 非会員の購入許可
+	
 	/**
 	 * コンストラクタ
 	 */
 	function __construct()
 	{
-		global $gInstanceManager;
-		
 		// 親クラスを呼び出す
 		parent::__construct();
 		
@@ -42,11 +41,11 @@ class ec_mainLoginWidgetContainer extends BaseWidgetContainer
 		//$this->db = new ec_mainOrderDb();
 		$this->mainDb = new ec_mainDb();
 		$this->memberDb = new ec_mainMemberDb();
-		$this->sysDb = $gInstanceManager->getSytemDbObject();
+		$this->sysDb = $this->gInstance->getSytemDbObject();
 		$this->orderDb = new ec_mainOrderDb();
 		
 		// メール連携オブジェクト取得
-		$this->ecMailObj = $gInstanceManager->getObject(self::MAIL_OBJ_ID);
+		$this->ecMailObj = $this->gInstance->getObject(self::MAIL_OBJ_ID);
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -73,26 +72,20 @@ class ec_mainLoginWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gAccessManager;
-		global $gPageManager;
-		global $gInstanceManager;
-
-		$langId	= $gEnvManager->getCurrentLanguage();		// 表示言語を取得
+		$langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
 		$act = $request->trimValueOf('act');
 		$forward = $request->trimValueOf(M3_REQUEST_PARAM_FORWARD);		// 画面遷移用パラメータ
 
-		// ログイン画面からデフォルトの遷移先は配送入力画面。変更する場合は、「forward」パラメータを設定する
+		// ログイン画面からデフォルトの遷移先は注文処理画面。変更する場合は、「forward」パラメータを設定する
 		// ログイン状態を取得
-		if ($gEnvManager->isCurrentUserLogined()){
+		if ($this->gEnv->isCurrentUserLogined()){
 			if (empty($forward)){
-				// 既にログイン中のときは、配送先指定画面へ
-				$deliveryPage = $gEnvManager->createCurrentPageUrl() . '&task=delivery';
-				//$deliveryPage = $gEnvManager->createCurrentPageUrl();
-				$gPageManager->redirect($deliveryPage);
+				// 既にログイン中のときは、注文開始画面へ
+				$orderPage = $this->gEnv->createCurrentPageUrl() . '&task=order';
+				$this->gPage->redirect($orderPage);
 			} else {
-				$forwardPage = $gEnvManager->createCurrentPageUrl() . '&' . $forward;
-				$gPageManager->redirect($forwardPage);
+				$forwardPage = $this->gEnv->createCurrentPageUrl() . '&' . $forward;
+				$this->gPage->redirect($forwardPage);
 			}
 			return;
 		}
@@ -102,12 +95,11 @@ class ec_mainLoginWidgetContainer extends BaseWidgetContainer
 			$password = $request->trimValueOf('password');
 
 			// ユーザ認証
-			if ($gAccessManager->userLoginByAccount($account, $password)){
+			if ($this->gAccess->userLoginByAccount($account, $password)){
 				// 初回ログインのときは、仮会員を正会員にする
-				$userId = $gEnvManager->getCurrentUserId();
+				$userId = $this->gEnv->getCurrentUserId();
 				if ($userId != 0){
-					//$ret = $this->orderDb->makeTmpMemberToProperMember($userId);
-					$ret = $gInstanceManager->getObject(self::EC_LIB_ID)->makeTmpMemberToProperMember($userId);
+					$ret = $this->gInstance->getObject(self::EC_LIB_ID)->makeTmpMemberToProperMember($userId);
 					if ($ret){
 						$this->sysDb->makeNormalLoginUser($userId);// 一般ログインユーザに設定
 					
@@ -116,37 +108,43 @@ class ec_mainLoginWidgetContainer extends BaseWidgetContainer
 					}
 				}
 				if (empty($forward)){
-					// 配送先指定画面へ
-					$deliveryPage = $gEnvManager->createCurrentPageUrl() . '&task=delivery';
-					//$deliveryPage = $gEnvManager->createCurrentPageUrl();
-					$gPageManager->redirect($deliveryPage);
+					// 注文開始画面へ
+					$orderPage = $this->gEnv->createCurrentPageUrl() . '&task=order';
+					$this->gPage->redirect($orderPage);
 				} else {
-					$forwardPage = $gEnvManager->createCurrentPageUrl() . '&' . $forward;
-					$gPageManager->redirect($forwardPage);
+					$forwardPage = $this->gEnv->createCurrentPageUrl() . '&' . $forward;
+					$this->gPage->redirect($forwardPage);
 				}
 				return;
 			} else {
 				// ログイン状態を削除
-				$gAccessManager->userLogout();
+				$this->gAccess->userLogout();
 				
 				$this->tmpl->addVar("_widget", "message", 'ログインに失敗しました');
 			}
-		} else if ($act == 'ec_maillogin'){			// 会員ログインのとき
+		} else if ($act == 'ec_maillogin'){			// メールからの会員ログインのとき
 			// メールからのアクセスの場合は、ログイン後最初にパスワードを変更する
 			$account = $request->trimValueOf('account');
 			$pwd = $request->trimValueOf('pwd');
-			//$forward = 'task=';		// トップ画面へ遷移
 			$forward = 'task=changepwd';		// パスワードを変更
 			
 			$this->tmpl->addVar("_widget", "ec_account", $account);
 			$this->tmpl->addVar("_widget", "ec_password", $pwd);
 			$this->tmpl->addVar("_widget", "savepwd", $pwd);
-			//$this->tmpl->addVar('_widget', 'password_readonly', 'readonly');
 			$this->tmpl->setAttribute('field_regmember', 'visibility', 'hidden');// 会員登録への遷移を削除
 		}
+		if ($act != 'ec_maillogin'){
+			// 非会員の購入を許可している場合は、遷移可能にする
+			$value = $this->mainDb->getConfig(self::CF_PERMIT_NON_MEMBER_ORDER);
+			if (!empty($value)){
+				$this->tmpl->setAttribute('field_nonmember', 'visibility', 'visible');
+			}
+		}
+		
+		// パラメータを画面に埋め込む
+		$this->tmpl->addVar("field_regmember", "url_regmember", $this->gEnv->createCurrentPageUrl() . '&task=regmember');		// 会員登録画面遷移用
+		$this->tmpl->addVar("field_nonmember", "url_order", $this->gEnv->createCurrentPageUrl() . '&task=order');				// 購入画面遷移用
 		$this->tmpl->addVar("_widget", "forward", $forward);		// 遷移先を維持
-		// ディレクトリを設定
-		$this->tmpl->addVar("_widget", "script_url", $gEnvManager->getScriptsUrl());
 	}
 }
 ?>
