@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainWidgetContainer.php 1583 2009-03-16 04:16:39Z fishbone $
+ * @version    SVN: $Id: ec_mainWidgetContainer.php 1670 2009-03-30 07:21:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -56,6 +56,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 				case 'order';			// 注文開始
 				case 'regcustomer';			// 購入者情報入力
 				case 'delivery';		// 配送先入力
+				case 'delivmethod';		// 配送方法選択
 				case 'payment';			// 支払い
 				case 'confirm';			// 確認
 				case 'complete';		// 手続き完了
@@ -63,11 +64,6 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 				case 'changepwd';			// パスワード変更
 				case 'orderhistory';			// 注文履歴
 					// ログイン状態を取得
-					/*$userInfo = $this->gEnv->getCurrentUserInfo();
-					if (is_null($userInfo)){		// ログインされていない場合
-						$this->SetMsg(0, "ログインが必要です");
-						return true;
-					}*/
 					if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
 						$this->SetMsg(0, "ログインが必要です");
 						return true;
@@ -80,11 +76,6 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 				case 'changepwd';		// パスワード変更
 				case 'orderhistory';	// 注文履歴
 					// ログイン状態を取得
-					/*$userInfo = $this->gEnv->getCurrentUserInfo();
-					if (is_null($userInfo)){		// ログインされていない場合
-						$this->SetMsg(0, "ログインが必要です");
-						return true;
-					}*/
 					if (!$this->gEnv->isCurrentUserLogined()){		// ログインされていない場合
 						$this->SetMsg(0, "ログインが必要です");
 						return true;
@@ -95,12 +86,12 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 		// ##### 遷移先を決定 #####
 		if ($task == 'order'){
 			if ($this->gEnv->isCurrentUserLogined()){		// ユーザがログインしている場合(会員の場合)
-				// 注文の画面遷移(配送先入力→支払い方法入力→確認)
+				// 注文の画面遷移(配送先入力→配送方法選択→支払い方法入力→確認)
 				$orderPage = $this->gEnv->createCurrentPageUrl() . '&task=delivery';// 配送先入力
 				$this->gPage->redirect($orderPage);
 				return true;
 			} else {			// 非会員の購入の場合
-				// 注文の画面遷移(購入者情報入力→配送先入力→支払い方法入力→確認)
+				// 注文の画面遷移(購入者情報入力→配送先入力→配送方法選択→支払い方法入力→確認)
 				$orderPage = $this->gEnv->createCurrentPageUrl() . '&task=regcustomer';// 購入者情報入力
 				$this->gPage->redirect($orderPage);
 				return true;
@@ -120,6 +111,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 			case 'regmember';			// 会員登録
 			case 'regcustomer';			// 購入者情報入力
 			case 'delivery';		// 配送
+			case 'delivmethod';		// 配送方法選択
 			case 'payment';			// 支払い
 			case 'confirm';			// 確認
 			case 'complete';		// 手続き完了
@@ -154,6 +146,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 			case 'order';			// 注文開始
 			case 'regcustomer';			// 購入者情報入力
 			case 'delivery';		// 配送
+			case 'delivmethod';		// 配送方法選択
 			case 'payment';			// 支払い
 			case 'confirm';			// 確認
 			case 'complete';		// 手続き完了
@@ -184,6 +177,7 @@ class ec_mainWidgetContainer extends BaseWidgetContainer
 			case 'order';			// 注文開始
 			case 'regcustomer';			// 購入者情報入力
 			case 'delivery';		// 配送
+			case 'delivmethod';		// 配送方法選択
 			case 'payment';			// 支払い
 			case 'confirm';			// 確認
 			case 'complete';		// 手続き完了
