@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: productDb.php 976 2008-09-03 07:51:58Z fishbone $
+ * @version    SVN: $Id: productDb.php 1714 2009-04-07 03:18:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -316,40 +316,43 @@ class productDb extends BaseDb
 		return $ret;
 	}
 	/**
-	 * 商品の新規追加
+	 * 商品の新規追加、更新
 	 *
-	 * @param int	  $id			商品ID
+	 * @param int     $serial		シリアル番号(0=新規追加、0以外=更新)
+	 * @param int	  $id			商品ID(0=商品ID新規作成)
 	 * @param string  $lang			言語ID
-	 * @param string  $name			名前
-	 * @param string  $code			商品コード
-	 * @param int     $productType	商品種別(1=単品商品、2=セット商品、3=オプション商品)
-	 * @param int     $category		カテゴリーID
-	 * @param int     $index		表示順
-	 * @param bool    $visible		表示、非表示
-	 * @param int     $unitType		単位
-	 * @param float   $unitQuantity	数量
+	 * @param array   $otherParams	商品情報その他の値
 	 * @param int     $stockCount	表示在庫数
-	 * @param string  $description	説明
-	 * @param string  $description_short	簡易説明
-	 * @param string  $keyword		検索キーワード
-	 * @param string  $url			詳細説明URL
-	 * @param string  $taxType		課税種別
-	 * @param string  $adminNote	管理者用備考
 	 * @param array   $prices		価格情報の配列
 	 * @param array   $images		画像の配列
 	 * @param array   $statuses		商品スタータスの配列
 	 * @param array   $categories	商品カテゴリーの配列
-	 * @param int     $userId		更新者ユーザID
 	 * @param int     $newSerial	新規シリアル番号
 	 * @return bool					true = 成功、false = 失敗
 	 */
-	function addProduct($id, $lang, $name, $code, $productType, $category, $index, $visible, $unitType, $unitQuantity, $stockCount,
-								$description, $description_short, $keyword, $url, $taxType, $adminNote, 
-								$prices, $images, $statuses, $categories, $userId, &$newSerial)
+	function updateProduct($serial, $id, $lang, $otherParams, $stockCount, $prices, $images, $statuses, $categories, &$newSerial)
 	{
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		$newSerial = 0;
 		$startTran = false;			// この関数でトランザクションを開始したかどうか
+		$updateFields = array();	// 更新するフィールド名
+		$updateFields[] = 'pt_name';			// 商品名
+		$updateFields[] = 'pt_code';			// 商品コード
+		$updateFields[] = 'pt_sort_order';			// 表示順
+		$updateFields[] = 'pt_visible';				// 表示するかどうか
+		$updateFields[] = 'pt_product_type';		// 商品種別(1=単品商品、2=セット商品、3=オプション商品)
+		$updateFields[] = 'pt_unit_type_id';		// 選択単位
+		$updateFields[] = 'pt_unit_quantity';		// 数量
+		$updateFields[] = 'pt_description';			// 説明
+		$updateFields[] = 'pt_description_short';	// 簡易説明
+		$updateFields[] = 'pt_search_keyword';		// 検索キーワード
+		$updateFields[] = 'pt_site_url';			// 詳細情報URL
+		$updateFields[] = 'pt_tax_type_id';			// 税種別
+		$updateFields[] = 'pt_admin_note';		// 管理者用備考
+		$updateFields[] = 'pt_deliv_type';		// 配送タイプ
+		$updateFields[] = 'pt_deliv_fee';		// 配送単価
+		$updateFields[] = 'pt_weight';			// 配送基準重量
 						
 		// トランザクション開始
 		if (!$this->isInTransaction()){
@@ -357,43 +360,97 @@ class productDb extends BaseDb
 			$startTran = true;
 		}
 		
-		if ($id == 0){		// IDが0のときは、商品IDを新規取得
-			// IDを決定する
-			$queryStr = 'select max(pt_id) as mid from product ';
-			$ret = $this->selectRecord($queryStr, array(), $row);
-			if ($ret){
-				$pId = $row['mid'] + 1;
+		if (empty($serial)){		// 新規追加のとき
+			if ($id == 0){		// IDが0のときは、商品IDを新規取得
+				// IDを決定する
+				$queryStr = 'SELECT MAX(pt_id) AS mid FROM product ';
+				$ret = $this->selectRecord($queryStr, array(), $row);
+				if ($ret){
+					$pId = $row['mid'] + 1;
+				} else {
+					$pId = 1;
+				}
 			} else {
-				$pId = 1;
+				$pId = $id;
 			}
-		} else {
-			$pId = $id;
-		}
-		// 前レコードの削除状態チェック
-		$historyIndex = 0;
-		$queryStr = 'SELECT * FROM product ';
-		$queryStr .=  'WHERE pt_id = ? ';
-		$queryStr .=    'AND pt_language_id = ? ';
-		$queryStr .=  'ORDER BY pt_history_index DESC ';
-		$queryStr .=    'LIMIT 1';
-		$ret = $this->selectRecord($queryStr, array($pId, $lang), $row);
-		if ($ret){
-			if (!$row['pt_deleted']){		// レコード存在していれば終了
+			// 前レコードの削除状態チェック
+			$historyIndex = 0;
+			$queryStr = 'SELECT * FROM product ';
+			$queryStr .=  'WHERE pt_id = ? ';
+			$queryStr .=    'AND pt_language_id = ? ';
+			$queryStr .=  'ORDER BY pt_history_index DESC ';
+			$queryStr .=    'LIMIT 1';
+			$ret = $this->selectRecord($queryStr, array($pId, $lang), $row);
+			if ($ret){
+				if (!$row['pt_deleted']){		// レコード存在していれば終了
+					if ($startTran) $this->endTransaction();
+					return false;
+				}
+				$historyIndex = $row['pt_history_index'] + 1;
+			}
+		} else {		// 更新のとき
+			// 指定のシリアルNoのレコードが削除状態でないかチェック
+			$historyIndex = 0;		// 履歴番号
+			$queryStr  = 'SELECT * FROM product ';
+			$queryStr .=   'WHERE pt_serial = ? ';
+			$ret = $this->selectRecord($queryStr, array($serial), $row);
+			if ($ret){		// 既に登録レコードがあるとき
+				if ($row['pt_deleted']){		// レコードが削除されていれば終了
+					if ($startTran) $this->endTransaction();
+					return false;
+				}
+				$historyIndex = $row['pt_history_index'] + 1;
+			} else {		// 存在しない場合は終了
 				if ($startTran) $this->endTransaction();
 				return false;
 			}
-			$historyIndex = $row['pt_history_index'] + 1;
+			$pId = $row['pt_id'];
+			$lang = $row['pt_language_id'];
+		
+			// 古いレコードを削除
+			$queryStr  = 'UPDATE product ';
+			$queryStr .=   'SET pt_deleted = true, ';	// 削除
+			$queryStr .=     'pt_update_user_id = ?, ';
+			$queryStr .=     'pt_update_dt = ? ';
+			$queryStr .=   'WHERE pt_serial = ?';
+			$this->execStatement($queryStr, array($userId, $now, $serial));
 		}
-		// データを追加
-		$queryStr = 'INSERT INTO product ';
-		$queryStr .=  '(pt_id, pt_language_id, pt_history_index, pt_name, pt_code, pt_product_type, pt_category_id, pt_sort_order, pt_visible, pt_unit_type_id, pt_unit_quantity, pt_description, pt_description_short, pt_search_keyword, pt_site_url, pt_tax_type_id, pt_admin_note, pt_create_user_id, pt_create_dt) ';
+		// ##### データを追加 #####
+		// キーを取得
+		$keys = array_keys($otherParams);
+		
+		// クエリー作成
+		$queryStr = 'INSERT INTO product (pt_id, pt_language_id, pt_history_index, ';
+		$valueStr = '(?, ?, ?, ';
+		$values = array($pId, $lang, $historyIndex);
+		for ($i = 0; $i < count($keys); $i++){
+			$queryStr .= $keys[$i] . ', ';
+			$valueStr .= '?, ';
+			$values[] = $otherParams[$keys[$i]];
+		}
+
+		// 更新の場合、値が設定されていない場合は、旧レコード値を設定
+		if (!empty($serial)){
+			for ($i = 0; $i < count($updateFields); $i++){
+				$fieldName = $updateFields[$i];
+				if (!in_array($fieldName, $keys)){		// フィールドがないとき
+					$queryStr .= $fieldName . ', ';
+					$valueStr .= '?, ';
+					$values[] = $row[$fieldName];
+				}
+			}
+		}
+		
+		// レコードを追加
+		$queryStr .= 'pt_create_user_id, pt_create_dt) ';
+		$valueStr .= '?, ?)';
+		$values = array_merge($values, array($userId, $now));
 		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($pId, $lang, $historyIndex, $name, $code, $productType, $category, $index, $visible, 
-										$unitType, $unitQuantity, $description, $description_short, $keyword, $url, $taxType, $adminNote, $userId, $now));
+		$queryStr .=  $valueStr;
+		$this->execStatement($queryStr, $values);
 
 		// 新規のシリアル番号取得
-		$queryStr = 'select max(pt_serial) as ns from product ';
+		$queryStr = 'SELECT MAX(pt_serial) AS ns FROM product ';
 		$ret = $this->selectRecord($queryStr, array(), $row);
 		if ($ret) $newSerial = $row['ns'];
 		
@@ -459,172 +516,25 @@ class productDb extends BaseDb
 		if ($startTran) $ret = $this->endTransaction();
 		return $ret;
 	}
-	/**
-	 * 商品の更新
-	 *
-	 * @param int     $serial		シリアル番号
-	 * @param string  $name			名前
-	 * @param string  $code			商品コード
-	 * @param int     $category		カテゴリーID
-	 * @param int     $index		表示順
-	 * @param bool    $visible		表示、非表示
-	 * @param int     $unitType		単位
-	 * @param float   $unitQuantity	数量
-	 * @param int     $stockCount	表示在庫数
-	 * @param string  $description	説明
-	 * @param string  $description_short	簡易説明
-	 * @param string  $keyword		検索キーワード
-	 * @param string  $url			詳細説明URL
-	 * @param string  $taxType		課税種別
-	 * @param string  $adminNote	管理者用備考
-	 * @param array   $prices		価格情報の配列
-	 * @param array   $images		画像の配列
-	 * @param array   $statuses		商品スタータスの配列
-	 * @param array   $categories	商品カテゴリーの配列
-	 * @param int     $userId		更新者ユーザID
-	 * @param int     $newSerial	新規シリアル番号
-	 * @return bool					true = 成功、false = 失敗
-	 */
-	function updateProduct($serial, $name, $code, $category, $index, $visible, $unitType, $unitQuantity, $stockCount, $description, $description_short, $keyword, $url, $taxType, $adminNote,
-								$prices, $images, $statuses, $categories, $userId, &$newSerial)
-	{
-		$startTran = false;			// この関数でトランザクションを開始したかどうか
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		$newSerial = 0;
-				
-		// トランザクション開始
-		if (!$this->isInTransaction()){
-			$this->startTransaction();
-			$startTran = true;
-		}
-		
-		// 指定のシリアルNoのレコードが削除状態でないかチェック
-		$historyIndex = 0;		// 履歴番号
-		$queryStr  = 'select * from product ';
-		$queryStr .=   'where pt_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
-		if ($ret){		// 既に登録レコードがあるとき
-			if ($row['pt_deleted']){		// レコードが削除されていれば終了
-				//$this->endTransaction();
-				if ($startTran) $this->endTransaction();
-				return false;
-			}
-			$historyIndex = $row['pt_history_index'] + 1;
-		} else {		// 存在しない場合は終了
-			//$this->endTransaction();
-			if ($startTran) $this->endTransaction();
-			return false;
-		}
-		$pId = $row['pt_id'];
-		$lang = $row['pt_language_id'];
-		
-		// 古いレコードを削除
-		$queryStr  = 'UPDATE product ';
-		$queryStr .=   'SET pt_deleted = true, ';	// 削除
-		$queryStr .=     'pt_update_user_id = ?, ';
-		$queryStr .=     'pt_update_dt = ? ';
-		$queryStr .=   'WHERE pt_serial = ?';
-		$this->execStatement($queryStr, array($userId, $now, $serial));
-		
-		// 新規レコード追加
-		$queryStr = 'INSERT INTO product ';
-		$queryStr .=  '(pt_id, pt_language_id, pt_history_index, pt_name, pt_code, pt_product_type, pt_category_id, pt_sort_order, pt_visible, pt_unit_type_id, pt_unit_quantity, pt_description, pt_description_short, pt_search_keyword, pt_site_url, pt_tax_type_id, pt_admin_note, pt_create_user_id, pt_create_dt) ';
-		$queryStr .=  'VALUES ';
-		$queryStr .=  '(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)';
-		$this->execStatement($queryStr, array($row['pt_id'], $row['pt_language_id'], $historyIndex,
-							$name, $code, $row['pt_product_type'], $category, $index, $visible, $unitType, $unitQuantity, $description, 
-							$description_short, $keyword, $url, $taxType, $adminNote, $userId, $now));
-		
-		// 新規のシリアル番号取得
-		$queryStr = 'select max(pt_serial) as ns from product ';
-		$ret = $this->selectRecord($queryStr, array(), $row);
-		if ($ret) $newSerial = $row['ns'];
-		
-		// 表示在庫数更新
-		$queryStr = 'SELECT * FROM product_record ';
-		$queryStr .=  'WHERE pe_product_id = ? ';
-		$queryStr .=    'AND pe_language_id = ? ';
-		$ret = $this->selectRecord($queryStr, array($pId, $lang), $stockRow);
-		if ($ret){	// データが存在するとき
-			// データを更新
-			$queryStr  = 'UPDATE product_record ';
-			$queryStr .=   'SET pe_stock_count = ?, ';
-			$queryStr .=     'pe_update_user_id = ?, ';
-			$queryStr .=     'pe_update_dt = ? ';
-			$queryStr .=   'WHERE pe_serial = ?';
-			$this->execStatement($queryStr, array($stockCount, $userId, $now, $stockRow['pe_serial']));
-		} else {
-			$queryStr = 'INSERT INTO product_record ';
-			$queryStr .=  '(pe_product_id, pe_language_id, pe_stock_count, pe_update_user_id, pe_update_dt) ';
-			$queryStr .=  'VALUES ';
-			$queryStr .=  '(?, ?, ?, ?, ?)';
-			$this->execStatement($queryStr, array($pId, $lang, $stockCount, $userId, $now));
-		}
-		
-		// 価格の更新
-		for ($i = 0; $i < count($prices); $i++){
-			$price = $prices[$i];
-			$ret = $this->updatePrice($pId, $lang, $price[0], $price[1], $price[2], $price[3], $price[4], $userId, $now);
-			if (!$ret){
-				//$this->endTransaction();
-				if ($startTran) $this->endTransaction();
-				return false;
-			}
-		}
-		
-		// 画像の更新
-		for ($i = 0; $i < count($images); $i++){
-			$image = $images[$i];
-			$ret = $this->updateImage(2/* 商品画像 */, $pId, $lang, $image[0], $image[1], $image[2], $userId, $now);
-			if (!$ret){
-				//$this->endTransaction();
-				if ($startTran) $this->endTransaction();
-				return false;
-			}
-		}
-		
-		// 商品ステータスの更新
-		// ***** updateProductStatus()は、$statusesの値が存在していることが前提なので注意 *****
-		for ($i = 0; $i < count($statuses); $i++){
-			$status = $statuses[$i];
-			$ret = $this->updateProductStatus($pId, $lang, $status[0], $status[1], $userId, $now);
-			if (!$ret){
-				if ($startTran) $this->endTransaction();
-				return false;
-			}
-		}
-		// 商品カテゴリーの更新
-		for ($i = 0; $i < count($categories); $i++){
-			$ret = $this->updateProductCategory($newSerial, $i, $categories[$i]);
-			if (!$ret){
-				if ($startTran) $this->endTransaction();
-				return false;
-			}
-		}
-		
-		// トランザクション確定
-		if ($startTran) $ret = $this->endTransaction();
-		return $ret;
-	}
 	/**
 	 * 商品の削除
 	 *
-	 * @param int $serialNo			シリアルNo
-	 * @param int $userId			ユーザID(データ更新者)
+	 * @param int $serial			シリアルNo
 	 * @return						true=成功、false=失敗
 	 */
-	function delProduct($serialNo, $userId)
+	function delProduct($serial)
 	{
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
 		$now = date("Y/m/d H:i:s");	// 現在日時
 				
 		// トランザクション開始
 		$this->startTransaction();
 		
 		// 指定のシリアルNoのレコードが削除状態でないかチェック
-		$queryStr  = 'select * from product ';
-		$queryStr .=   'where pt_deleted = false ';		// 未削除
-		$queryStr .=     'and pt_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serialNo), $row);
+		$queryStr  = 'SELECT * FROM product ';
+		$queryStr .=   'WHERE pt_deleted = false ';		// 未削除
+		$queryStr .=     'AND pt_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
 		if (!$ret){		// 存在しない場合は終了
 			$this->endTransaction();
 			return false;
@@ -636,7 +546,7 @@ class productDb extends BaseDb
 		$queryStr .=     'pt_update_user_id = ?, ';
 		$queryStr .=     'pt_update_dt = now() ';
 		$queryStr .=   'WHERE pt_serial = ?';
-		$this->execStatement($queryStr, array($userId, $serialNo));
+		$this->execStatement($queryStr, array($userId, $serial));
 		
 		// 価格レコードを削除
 		$queryStr  = 'UPDATE product_price ';
@@ -677,20 +587,20 @@ class productDb extends BaseDb
 	 * 商品IDで削除
 	 *
 	 * @param int $serial			シリアルNo
-	 * @param int $userId			ユーザID(データ更新者)
 	 * @return						true=成功、false=失敗
 	 */
-	function delProductById($serial, $userId)
+	function delProductById($serial)
 	{
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
 		$now = date("Y/m/d H:i:s");	// 現在日時
 				
 		// トランザクション開始
 		$this->startTransaction();
 		
 		// 商品IDを取得
-		$queryStr  = 'select * from product ';
-		$queryStr .=   'where pt_deleted = false ';		// 未削除
-		$queryStr .=     'and pt_serial = ? ';
+		$queryStr  = 'SELECT * FROM product ';
+		$queryStr .=   'WHERE pt_deleted = false ';		// 未削除
+		$queryStr .=     'AND pt_serial = ? ';
 		$ret = $this->selectRecord($queryStr, array($serial), $row);
 		if (!$ret){		// 存在しない場合は終了
 			$this->endTransaction();
