@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_imageWidgetContainer.php 962 2008-08-31 03:57:04Z fishbone $
+ * @version    SVN: $Id: admin_imageWidgetContainer.php 1424 2009-01-07 04:29:09Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -177,11 +177,13 @@ class admin_imageWidgetContainer extends BaseWidgetContainer
 				$ret = $this->updateWidgetParamObj($this->paramObj);
 				
 				// 画面定義更新
-				if ($ret) $ret = $this->sysDb->updateWidgetConfigId($gEnvManager->getCurrentWidgetId(), $defSerial, $newConfigId, $name);
+				if ($ret && !empty($defSerial)){
+					$ret = $this->sysDb->updateWidgetConfigId($gEnvManager->getCurrentWidgetId(), $defSerial, $newConfigId, $name);
+				}
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
 					
-					$defConfigId = $newConfigId;		// 定義定義IDを更新
+					if (!empty($defSerial)) $defConfigId = $newConfigId;		// 定義定義IDを更新
 					$this->configId = $newConfigId;		// 定義定義IDを更新
 					$replaceNew = true;			// データ再取得
 				} else {
@@ -230,14 +232,14 @@ class admin_imageWidgetContainer extends BaseWidgetContainer
 
 				$ret = $this->updateWidgetParamObj($this->paramObj);
 			
-				if (empty($defConfigId)){		// 画面定義の定義IDが設定されていないときは設定
+				if (empty($defConfigId) && !empty($defSerial)){		// 画面定義の定義IDが設定されていないときは設定
 					// 画面定義更新
 					if ($ret) $ret = $this->sysDb->updateWidgetConfigId($gEnvManager->getCurrentWidgetId(), $defSerial, $this->configId, $name);
 				}
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 				
-					if (empty($defConfigId)){		// 画面定義の定義IDが設定されていないときは設定
+					if (empty($defConfigId) && !empty($defSerial)){		// 画面定義の定義IDが設定されていないときは設定
 						$defConfigId = $this->configId;		// 定義定義IDを更新
 					}
 					$replaceNew = true;			// データ再取得
@@ -303,7 +305,7 @@ class admin_imageWidgetContainer extends BaseWidgetContainer
 				$this->serialNo = $this->configId;
 				
 				// 新規作成でないときは、メニューを変更不可にする
-				if (!empty($defConfigId)) $this->tmpl->addVar("_widget", "id_disabled", 'disabled');
+				if (!empty($defConfigId) && !empty($defSerial)) $this->tmpl->addVar("_widget", "id_disabled", 'disabled');
 			}
 		}
 		// 設定項目選択メニュー作成
