@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photoslideWidgetContainer.php 954 2008-08-29 06:55:55Z fishbone $
+ * @version    SVN: $Id: photoslideWidgetContainer.php 1526 2009-02-27 02:33:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -105,7 +105,7 @@ class photoslideWidgetContainer extends BaseWidgetContainer
 	 * @param object         $param			任意使用パラメータ。
 	 * @return string 						CSS文字列。出力しない場合は空文字列を設定。
 	 */
-	function _addCssData($request, &$param)
+	function _addCssToHead($request, &$param)
 	{
 		if ($this->visible){
 			return $this->css;
