@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: static_contentWidgetContainer.php 896 2008-08-10 07:47:55Z fishbone $
+ * @version    SVN: $Id: static_contentWidgetContainer.php 1343 2008-12-12 07:12:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -59,14 +59,10 @@ class static_contentWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		global $gEnvManager;
-		global $gDesignManager;
-		global $gTextConvManager;
-		
-		$this->langId = $gEnvManager->getCurrentLanguage();
+		$this->langId = $this->gEnv->getCurrentLanguage();
 		
 		// 定義ID取得
-		$configId = $gEnvManager->getCurrentWidgetConfigId();
+		$configId = $this->gEnv->getCurrentWidgetConfigId();
 		if (empty($configId)) $configId = self::DEFAULT_CONFIG_ID;
 		
 		// パラメータオブジェクトを取得
@@ -87,27 +83,27 @@ class static_contentWidgetContainer extends BaseWidgetContainer
 			}
 		}
 		if ($i < count($paramObj)){		// 該当する定義IDのデータが取得できたとき
-			$this->tmpl->setAttribute('show_html', 'visibility', 'visible');
-			
-			// 	テーブルのパラメータ
-			$this->tmpl->addVar("show_html", "title_param", $gDesignManager->getDefaultWidgetTableParam());
-		
-			// タイトルの設定
-			if ($showTitle){		// タイトル表示のとき
-				$this->tmpl->setAttribute('show_title', 'visibility', 'visible');
-				$this->tmpl->addVar("show_title", "title", $this->convertToDispString($name));
-			}
-		
 			// コンテンツを取得
 			$ret = $this->db->getContentByContentId(self::CONTENT_TYPE, $contentId, $this->langId, $row);
 			if ($ret){
-				$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $row['cn_html']);// アプリケーションルートを変換
-			}
-			// 登録したキーワードを変換
-			$gTextConvManager->convByKeyValue($html, $html, true/*改行コーをbrタグに変換*/);
+				// Magic3マクロ変換
+				$html = $this->convertM3ToHtml($row['cn_html']);
 				
-			// コンテンツを設定
-			$this->tmpl->addVar("show_html", "content", $html);
+				// 	テーブルのパラメータ
+				$this->tmpl->addVar("show_html", "title_param", $this->gDesign->getDefaultWidgetTableParam());
+		
+				// タイトルの設定
+				if ($showTitle){		// タイトル表示のとき
+					$this->tmpl->setAttribute('show_title', 'visibility', 'visible');
+					$this->tmpl->addVar("show_title", "title", $this->convertToDispString($name));
+				}
+
+				// コンテンツを設定
+				$this->tmpl->addVar("show_html", "content", $html);
+			
+				// ログインユーザに表示が制限されている場合は非表示
+				if ($this->gEnv->isCurrentUserLogined() || !$row['cn_user_limited']) $this->tmpl->setAttribute('show_html', 'visibility', 'visible');
+			}
 		}
 	}
 }
