@@ -1,12 +1,22 @@
 <?php
-// PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: plugin.php 1043 2008-09-26 12:22:24Z fishbone $
+/**
+ * プラグイン処理関係
+ *
+ * PHP versions 5
+ *
+ * LICENSE: This source file is licensed under the terms of the GNU General Public License.
+ *
+ * @package    Magic3 Framework
+ * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
+ * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
+ * @version    SVN: $Id: plugin.php 1108 2008-10-23 11:46:32Z fishbone $
+ * @link       http://www.magic3.org
+ */
 // Copyright (C)
 //   2002-2005 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
 // License: GPL v2 or (at your option) any later version
-//
-// Plugin related functions
 
 define('PKWK_PLUGIN_CALL_TIME_LIMIT', 768);
 
@@ -21,18 +31,22 @@ function set_plugin_messages($messages)
 // Check plugin '$name' is here
 function exist_plugin($name)
 {
-	global $vars;
+	//global $vars;
 	static $exist = array(), $count = array();
 
+	$page = WikiParam::getPage();
 	$name = strtolower($name);
 	if(isset($exist[$name])) {
-		if (++$count[$name] > PKWK_PLUGIN_CALL_TIME_LIMIT)
-			die('Alert: plugin "' . htmlspecialchars($name) .
-			'" was called over ' . PKWK_PLUGIN_CALL_TIME_LIMIT .
+		if (++$count[$name] > PKWK_PLUGIN_CALL_TIME_LIMIT){
+			/*die('Alert: plugin "' . htmlspecialchars($name) . '" was called over ' . PKWK_PLUGIN_CALL_TIME_LIMIT .
 			' times. SPAM or someting?<br />' . "\n" .
-			'<a href="' . get_script_uri() . '?cmd=edit&amp;page='.
-			rawurlencode($vars['page']) . '">Try to edit this page</a><br />' . "\n" .
+			'<a href="' . get_script_uri() . '?cmd=edit&amp;page='. rawurlencode($vars['page']) . '">Try to edit this page</a><br />' . "\n" .
+			'<a href="' . get_script_uri() . '">Return to frontpage</a>');*/
+			die('Alert: plugin "' . htmlspecialchars($name) . '" was called over ' . PKWK_PLUGIN_CALL_TIME_LIMIT .
+			' times. SPAM or someting?<br />' . "\n" .
+			'<a href="' . get_script_uri() . WikiParam::convQuery('?cmd=edit&amp;page='. rawurlencode($page)) . '">Try to edit this page</a><br />' . "\n" .
 			'<a href="' . get_script_uri() . '">Return to frontpage</a>');
+		}
 		return $exist[$name];
 	}
 	if (preg_match('/^\w{1,64}$/', $name) &&
@@ -47,7 +61,7 @@ function exist_plugin($name)
 		return FALSE;
 	}
 }
-
+// プラグイン処理のための関数名は、「_action」,「_convert」,「_inline」,「_init」
 // Check if plugin API 'action' exists
 function exist_plugin_action($name) {
 	return	function_exists('plugin_' . $name . '_action') ? TRUE : exist_plugin($name) ?
