@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: article.inc.php 1136 2008-10-27 03:06:23Z fishbone $
+ * @version    SVN: $Id: article.inc.php 1601 2009-03-21 05:51:06Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -121,7 +121,7 @@ function plugin_article_action()
 		$s_postdata = htmlspecialchars($postdata_input);
 		$postScript = $script . WikiParam::convQuery('?cmd=preview');
 		$body .= <<<EOD
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="refer" value="$s_refer" />
   <input type="hidden" name="digest" value="$s_digest" />
@@ -211,7 +211,7 @@ function plugin_article_convert()
 	$article_cols = PLUGIN_ARTICLE_COLS;
 	$postScript = $script . WikiParam::convQuery('?');
 	$string = <<<EOD
-<form action="$postScript" method="post">
+<form action="$postScript" method="post" class="form">
  <div>
   <input type="hidden" name="article_no" value="$article_no" />
   <input type="hidden" name="plugin" value="article" />
@@ -222,29 +222,10 @@ function plugin_article_convert()
   <label for="_p_article_subject_$article_no">$_btn_subject</label>
   <input type="text" name="subject" id="_p_article_subject_$article_no" size="$subject_cols" /><br />
   <textarea name="msg" class="wiki_edit" rows="$article_rows" cols="$article_cols">\n</textarea><br />
-  <input type="submit" name="article" value="$_btn_article" />
+  <input type="submit" class="button" name="article" value="$_btn_article" />
  </div>
 </form>
 EOD;
-/*
-	$string = <<<EOD
-<form action="$script" method="post">
- <div>
-  <input type="hidden" name="article_no" value="$article_no" />
-  <input type="hidden" name="plugin" value="article" />
-  <input type="hidden" name="digest" value="$s_digest" />
-  <input type="hidden" name="refer" value="$s_page" />
-  <label for="_p_article_name_$article_no">$_btn_name</label>
-  <input type="text" name="name" id="_p_article_name_$article_no" size="$name_cols" /><br />
-  <label for="_p_article_subject_$article_no">$_btn_subject</label>
-  <input type="text" name="subject" id="_p_article_subject_$article_no" size="$subject_cols" /><br />
-  <textarea name="msg" rows="$article_rows" cols="$article_cols">\n</textarea><br />
-  <input type="submit" name="article" value="$_btn_article" />
- </div>
-</form>
-EOD;
-*/
-
 	return $string;
 }
 ?>
